'use strict';

// Holds the list of modules which the injector will load before the current module is loaded
angular.module('linshareAdminApp', [
    'ui.bootstrap',
    'ui.router',
    'ngLocale',
    'ngSanitize',
    'ngResource',
    'ngRoute',
    'ngCookies',
    'ui.select',
    'ngTable',
    'http-auth-interceptor',
    'chieffancypants.loadingBar',
    'pascalprecht.translate',
    'tmh.dynamicLocale',
    'restangular',
    'checklist-model'
])

// Register work which needs to be performed on module loading
.config(['$provide', '$logProvider', '$translateProvider', 'RestangularProvider', 'uiSelectConfig', 'cfpLoadingBarProvider', 'tmhDynamicLocaleProvider', 'lsAppConfig',
  function($provide, $logProvider, $translateProvider, RestangularProvider, uiSelectConfig, cfpLoadingBarProvider, tmhDynamicLocaleProvider, lsAppConfig) {
    var debug = document.cookie.linshareDebug || lsAppConfig.debug;
    $logProvider.debugEnabled(debug);

    $translateProvider.useStaticFilesLoader({
      prefix: 'i18n/locale-',
      suffix: '.json'
    });
    $translateProvider.preferredLanguage('en');
    $translateProvider.addInterpolation('$translateMessageFormatInterpolation');
    $translateProvider.useMissingTranslationHandlerLog();
    $translateProvider.useCookieStorage();

    tmhDynamicLocaleProvider.localeLocationPattern('i18n/angular/angular-locale_{{locale}}.js');

    RestangularProvider.setBaseUrl(lsAppConfig.backendURL);
    RestangularProvider.setDefaultHeaders({'Content-Type': 'application/json'});
    RestangularProvider.addResponseInterceptor(function(data) {
      var newResponse = data;
      if (angular.isArray(data)) {
        angular.forEach(newResponse, function(value, key) {
          if (angular.isObject(value)) {
            newResponse[key].originalElement = angular.copy(value);
          }else{
            newResponse.originalElement = [];
            newResponse.originalElement[key] = angular.copy(value);
          }

        });
      } else if (angular.isObject(data)){
        newResponse.originalElement = angular.copy(data);
      }

      return newResponse;
    });
    RestangularProvider.addFullRequestInterceptor(function (element, operation, route, url, headers) {
      // Bypass basic authentication
      headers['WWW-No-Authenticate'] = 'linshare';
      if (element) {
        delete element.originalElement;
      }
      return element;
    });

    uiSelectConfig.theme = 'bootstrap';
    cfpLoadingBarProvider.includeSpinner = false;

    // Force reloading controller (https://github.com/angular-ui/ui-router/issues/582)
    $provide.decorator('$state', function($delegate, $rootScope) {
      $delegate.reinit = function() {
        this.go('.', {}, {reload: true});
      };
      $rootScope.$on('$stateChangeStart', function(event, state, params) {
        $delegate.next = state;
        $delegate.toParams = params;
      });
      return $delegate;
    });
}])

// Register work which should be performed when the injector is done loading all modules 
.run(['$rootScope', '$state', '$log', 'Restangular', 'Notification', 'lsAppConfig',
  function($rootScope, $state, $log, Restangular, Notification, lsAppConfig) {
    Restangular.setErrorInterceptor(function(response) {
      $log.error(response);
      if (response.status !== 200 && response.status !== 401 && response.status < 500) {
        Notification.addError(response.data);
      }
      if (response.status >= 500 && response.status < 600){
        Notification.addError(response);
      }
      return true;
    });
    if (lsAppConfig.debug) {
      $rootScope.$on('$stateChangeStart',function(event, toState, toParams){
        console.log('$stateChangeStart to '+toState.to+'- fired when the transition begins. toState,toParams : \n',toState, toParams);
      });
      $rootScope.$on('$stateChangeError',function(event, toState, toParams, fromState, fromParams){
        console.log('$stateChangeError - fired when an error occurs during transition.');
        console.log([event, toState, toParams, fromState, fromParams].join('\n'));
        console.log(arguments);
      });
      $rootScope.$on('$stateChangeSuccess',function(event, toState){
        console.log('$stateChangeSuccess to '+toState.name+'- fired once the state transition is complete.');
      });
      // $rootScope.$on('$viewContentLoading',function(event, viewConfig){
      //   // runs on individual scopes, so putting it in "run" doesn't work.
      //   console.log('$viewContentLoading - view begins loading - dom not rendered',viewConfig);
      // });
      $rootScope.$on('$viewContentLoaded',function(event){
        console.log('$viewContentLoaded - fired after dom rendered',event);
      });
      $rootScope.$on('$stateNotFound',function(event, unfoundState, fromState, fromParams){
        console.log('$stateNotFound '+unfoundState.to+'  - fired when a state cannot be found by its name.');
        console.log(unfoundState, fromState, fromParams);
      });
    }
  }
]);

'use strict';

angular.module('linshareAdminApp').config(['$stateProvider', '$urlRouterProvider',
  function($stateProvider, $urlRouterProvider) {
    //  For any unmatched url, redirect
    $urlRouterProvider.otherwise('/user/list');

    var funcAccountExpiration = function(currentUser, Functionality) {
      if (currentUser) {
        return Functionality.get(currentUser.domain , 'ACCOUNT_EXPIRATION');
      }
    };
    var funcRestrictedGuest = function(currentUser, Functionality) {
      if (currentUser) {
        return Functionality.get(currentUser.domain , 'RESTRICTED_GUEST');
      }
    };

    var enumRole = function(Enum) {
      return Enum.getOptions('role');
    };
    var enumLanguage = function(Enum) {
      return Enum.getOptions('language');
    };
    var enumLogAction = function(Enum) {
      return Enum.getOptions('log_action');
    };
    var enumDomainAccessRuleTypes = function(Enum) {
      return Enum.getOptions('domain_access_rule_type');
    };
    var enumUploadPropositionFieldTypes = function(Enum) {
      return Enum.getOptions('upload_proposition_rule_field_type');
    };
    var enumUploadPropositionOperatorTypes = function(Enum) {
      return Enum.getOptions('upload_proposition_rule_operator_type');
    };
    var enumUploadPropositionActionTypes = function(Enum) {
      return Enum.getOptions('upload_proposition_action_type');
    };
    var enumUploadPropositionMatchTypes = function(Enum) {
      return Enum.getOptions('upload_proposition_match_type');
    };
    var enumTechnicalAccountPermissionTypes = function(Enum) {
      return Enum.getOptions('technical_account_permission_type');
    };
    var enumUploadRequestStatus = function(Enum) {
      return Enum.getOptions('upload_request_status');
    };

    var authenticatedUser = function(Authentication) {
      return Authentication.getCurrentUser();
    };

    // Common views
    var domainTreeView = {
      templateUrl: 'ng_components/domain/domain_tree.tpl.html',
      controller: 'DomainTreeCtrl',
      resolve: {
        rootDomain: function(Domain, authenticatedUser) {
          return Domain.getDomainTree(authenticatedUser.domain);
        }
      }
    };

    $stateProvider
      .state('functionality', {
        abstract: true,
        url: '/functionality',
        templateUrl: 'ng_components/functionality/functionality.html',
        resolve: {
          treeType: function() {
            return 'read';
          },
          authenticatedUser: authenticatedUser
        },
        controller: function($scope, $state) {
          $scope.$state = $state;
        }
      })
      .state('functionality.list', {
        url: '/:domainId/list',
        views: {
          'tree': domainTreeView,
          'list': {
            templateUrl: 'ng_components/functionality/functionality_list.tpl.html',
            controller: 'FunctionalityListCtrl',
            resolve: {
              currentDomain: function(Domain, $stateParams) {
                return Domain.get($stateParams.domainId);
              },
              functionalities: function(Functionality, currentDomain) {
                return Functionality.getAll(currentDomain.identifier);
              }
            }
          }
        }
      })
      .state('functionality.detail', {
        url: '/:domainId/detail/:id',
        views: {
          'tree': domainTreeView,
          'detail': {
            templateUrl: 'ng_components/functionality/functionality_detail.tpl.html',
            controller: 'FunctionalityDetailCtrl',
            resolve: {
              currentDomain: function(Domain, $stateParams) {
                return Domain.get($stateParams.domainId);
              },
              currentFunctionality: function(Functionality, $stateParams) {
                return Functionality.getAll($stateParams.domainId).then(function(functionalities) {
                  return _.find(functionalities, {identifier: $stateParams.id});
                });
              }
            }
          }
        }
      })

      .state('mimepolicy', {
        abstract: true,
        url: '/mimepolicy',
        templateUrl: 'ng_components/mimepolicy/mimepolicy.html',
        resolve: {
          treeType: function() {
            return 'read';
          },
          authenticatedUser: authenticatedUser
        },
        controller: function($scope, $state) {
          $scope.$state = $state;
        }
      })
      .state('mimepolicy.list', {
        url: '/:domainId/list',
        views: {
          'tree': domainTreeView,
          'list': {
            templateUrl: 'ng_components/mimepolicy/mimepolicy_list.tpl.html',
            controller: 'MimePolicyListCtrl',
            resolve: {
              currentDomain: function(Domain, $stateParams) {
                return Domain.get($stateParams.domainId);
              },
              mimePolicies: function(MimePolicy, currentDomain) {
                return MimePolicy.getAll(currentDomain.identifier, true);
              }
            }
          }
        }
      })
      .state('mimepolicy.detail', {
        url: '/:domainId/detail/:id',
        views: {
          'detail': {
            templateUrl: 'ng_components/mimepolicy/mimepolicy_detail.tpl.html',
            controller: 'MimePolicyDetailCtrl',
            resolve: {
              currentDomain: function(Domain, $stateParams) {
                return Domain.get($stateParams.domainId);
              },
              currentMimePolicy: function($stateParams, MimePolicy) {
                 return MimePolicy.get($stateParams.id, true);
              }
            }
          }
        }
      })

      .state('user', {
        abstract: true,
        url: '/user',
        templateUrl: 'ng_components/user/user.html'
      })
      .state('user.list', {
        url: '/list',
        templateUrl: 'ng_components/user/user_list.tpl.html',
        controller: 'UserListCtrl'
      })
      .state('user.detail', {
        url: '/:uuid',
        resolve: {
          currentUser: function(User, $stateParams) {
            return User.get($stateParams.uuid);
          },
          maxExpiryDate: function(_funcAccountExpiration) {
            var date = new Date();
            var delta = _funcAccountExpiration.parameters[0].integer;
            if (_funcAccountExpiration.parameters.string === 'DAY') {
              date.setDay(date.getDay() + delta);
            } else if (_funcAccountExpiration.parameters.string === 'WEEK') {
              date.setWeek(date.getWeek() + delta);
            } else {
              date.setMonth(date.getMonth() + delta);
            }
            return date;
          },
          restrictedGuestStatus: function(_funcRestrictedGuest) {
            return _funcRestrictedGuest.activationPolicy.policy !== 'ALLOWED';
          },
          selectOptions: function(_enumRole, _enumLanguage) {
            return {
              userRoles: _.remove(_enumRole, function(role) {
                return role !== 'SYSTEM' && role !== 'SUPERADMIN' && role !== 'DELEGATION' && role !== 'UPLOAD_PROPOSITION';
              }),
              selectEnumLanguage: _enumLanguage
            };
          },
          _funcAccountExpiration: funcAccountExpiration,
          _funcRestrictedGuest: funcRestrictedGuest,
          _enumRole: enumRole,
          _enumLanguage: enumLanguage
        },
        templateUrl: 'ng_components/user/user_detail.tpl.html',
        controller: 'UserDetailCtrl'
      })

      .state('inconsistentuser', {
        abstract: true,
        url: '/inconsistentuser',
        templateUrl: 'ng_components/inconsistentuser/inconsistentuser.html',
        resolve: {
          allInconsistents: function(User) {
            return User.getAllInconsistent();
          }
        }
      })
      .state('inconsistentuser.list', {
        url: '/list',
        templateUrl: 'ng_components/inconsistentuser/inconsistentuser_list.tpl.html',
        controller: 'InconsistentUserListCtrl'
      })
      .state('inconsistentuser.detail', {
        url: '/:uuid',
        resolve: {
          currentUser: function(allInconsistents, $stateParams) {
            return _.find(allInconsistents, {uuid: $stateParams.uuid});
          },
          allDomains: function(Domain) {
            return Domain.getAll();
          }
        },
        templateUrl: 'ng_components/inconsistentuser/inconsistentuser_detail.tpl.html',
        controller: 'InconsistentUserDetailCtrl'
      })

      .state('thread', {
        abstract: true,
        url: '/group',
        templateUrl: 'ng_components/thread/thread.html'
      })
      .state('thread.list', {
        url: '/list',
        templateUrl: 'ng_components/thread/thread_list.tpl.html',
        controller: 'ThreadListCtrl'
      })
      .state('thread.detail', {
        url: '/:id',
        templateUrl: 'ng_components/thread/thread_detail.tpl.html',
        controller: 'ThreadDetailCtrl',
        resolve: {
          currentThread: function($stateParams, Thread) {
            if ($stateParams.id) {
              return Thread.get($stateParams.id);
            }
          }
        }
      })

      .state('mailinglist', {
        abstract: true,
        url: '/mailinglist',
        templateUrl: 'ng_components/mailinglist/mailinglist.html'
      })
      .state('mailinglist.list', {
        url: '/list',
        templateUrl: 'ng_components/mailinglist/mailinglist_list.tpl.html',
        controller: 'MailingListListCtrl',
        resolve: {
          mailingLists: function(MailingList) {
            return MailingList.getAll();
          }
        }
      })
      .state('mailinglist.detail', {
        url: '/:id',
        templateUrl: 'ng_components/mailinglist/mailinglist_detail.tpl.html',
        controller: 'MailingListDetailCtrl',
        resolve: {
          currentMailingList: function($stateParams, MailingList) {
            if ($stateParams.id) {
              return MailingList.get($stateParams.id);
            }
          }
        }
      })

      .state('audit', {
        abstract: true,
        templateUrl: 'ng_components/audit/audit.html'
      })
      .state('audit.form', {
        url: '/audit',
        views: {
          'form': {
            templateUrl: 'ng_components/audit/audit_form.tpl.html',
            controller: 'AuditFormCtrl',
            resolve: {
              selectOptions: function(_allDomains, _enumLogAction) {
                return {
                  domains: _allDomains,
                  actions: _enumLogAction
                };
              },
              authenticatedUser: authenticatedUser,
              _allDomains: function(Domain) {
                return Domain.getAll();
              },
              _enumLogAction: enumLogAction
            }
          }
        }
      })

      .state('ldapconnection', {
        abstract: true,
        url: '/ldapconnection',
        templateUrl: 'ng_components/ldapconnection/ldapconnection.html'
      })
      .state('ldapconnection.list', {
        url: '/list',
        templateUrl: 'ng_components/ldapconnection/ldapconnection_list.tpl.html',
        controller: 'LdapConnectionListCtrl',
        resolve: {
          ldapConnections: function(LdapConnection) {
            return LdapConnection.getAll();
          }
        }
      })
      .state('ldapconnection.detail', {
        url: '/:id?formState',
        templateUrl: 'ng_components/ldapconnection/ldapconnection_detail.tpl.html',
        controller: 'LdapConnectionDetailCtrl',
        resolve: {
          currentLdapConnection: function($stateParams, LdapConnection) {
            if ($stateParams.id) {
              return LdapConnection.get($stateParams.id);
            }
          }
        }
      })

      .state('domainpattern', {
        abstract: true,
        url: '/domainpattern',
        templateUrl: 'ng_components/domainpattern/domainpattern.html'
      })
      .state('domainpattern.list', {
        url: '/list',
        templateUrl: 'ng_components/domainpattern/domainpattern_list.tpl.html',
        controller: 'DomainPatternListCtrl',
        resolve: {
          domainPatterns: function(DomainPattern) {
            return DomainPattern.getAll();
          }
        }
      })
      .state('domainpattern.detail', {
        url: '/:id?formState',
        templateUrl: 'ng_components/domainpattern/domainpattern_detail.tpl.html',
        controller: 'DomainPatternDetailCtrl',
        resolve: {
          currentDomainPattern: function($stateParams, DomainPattern) {
            if ($stateParams.id) {
              return DomainPattern.get($stateParams.id);
            }
          },
          models: function(DomainPattern) {
            return DomainPattern.getAllModels();
          }
        }
      })

      .state('domain', {
        url: '/domain',
        abstract: true,
        templateUrl: 'ng_components/domain/domain.html',
        resolve: {
          treeType: function() {
            return 'edit';
          }
        },
        controller: function($scope, $state) {
          $scope.$state = $state;
        }
      })
      .state('domain.detail', {
        url: '/detail/:domainId?formState&domainType',
        resolve: {
          authenticatedUser: authenticatedUser
        },
        views : {
          'tree': domainTreeView,
          'detail': {
            templateUrl: 'ng_components/domain/domain_detail.tpl.html',
            controller: 'DomainDetailCtrl',
            resolve: {
              selectOptions: function(_allLdapConnections, _allDomainPatterns, _allDomainPolicies, _allMailConfigs, _allMimePolicies,  _enumRole, _enumLanguage) {
                return {
                  ldapConnectionIds: _.pluck(_allLdapConnections, 'identifier'),
                  domainPatternIds: _.pluck(_allDomainPatterns, 'identifier'),
                  domainPolicyIds: _.pluck(_allDomainPolicies, 'identifier'),
                  mailConfigs: _allMailConfigs,
                  mimePolicies: _allMimePolicies,
                  userRoles: _.remove(_enumRole, function(role) {
                    return role !== 'SYSTEM' && role !== 'SUPERADMIN' && role !== 'DELEGATION' && role !== 'UPLOAD_PROPOSITION';
                  }),
                  languages: _enumLanguage
                };
              },
              currentDomain: function(Domain, $stateParams) {
                if ($stateParams.domainId) {
                  return Domain.get($stateParams.domainId);
                }
              },
              _allLdapConnections: function(LdapConnection) {
                return LdapConnection.getAll();
              },
              _allDomainPatterns: function(DomainPattern) {
                return DomainPattern.getAll();
              },
              _allDomainPolicies: function(DomainPolicy) {
                return DomainPolicy.getAll();
              },
              _allMailConfigs: function(currentDomain, MailConfig) {
                if (currentDomain) {
                  return MailConfig.getAll(currentDomain.identifier, false);
                }
              },
              _allMimePolicies: function(currentDomain, MimePolicy) {
                if (currentDomain) {
                  return MimePolicy.getAll(currentDomain.identifier, false);
                }
              },
              _enumRole: enumRole,
              _enumLanguage: enumLanguage
            }
          }
        }
      })
     .state('domain.order', {
       url: '/order',
       templateUrl: 'ng_components/domain/domain_order.tpl.html',
       controller: 'DomainOrderCtrl',
       resolve: {
         domains: function(Domain) {
           return Domain.getAll();
         }
       }
     })

      .state('domainpolicy', {
        abstract: true,
        url: '/domainpolicy',
        templateUrl: 'ng_components/domainpolicy/domainpolicy.html'
      })
      .state('domainpolicy.list', {
        url: '/list',
        templateUrl: 'ng_components/domainpolicy/domainpolicy_list.tpl.html',
        controller: 'DomainPolicyListCtrl',
        resolve: {
          domainPolicies: function(DomainPolicy) {
            return DomainPolicy.getAll();
          }
        }
      })
      .state('domainpolicy.detail', {
        url: '/:id?formState',
        templateUrl: 'ng_components/domainpolicy/domainpolicy_detail.tpl.html',
        controller: 'DomainPolicyDetailCtrl',
        resolve: {
          selectOptions: function(_allDomains, _enumDomainAccessRuleTypes) {
            return {
              domains: _allDomains,
              domainAccessRuleTypes: _enumDomainAccessRuleTypes
            };
          },
          currentDomainPolicy: function($stateParams, DomainPolicy) {
            if ($stateParams.id) {
              return DomainPolicy.get($stateParams.id);
            }
          },
          _allDomains: function(Domain) {
            return Domain.getAll();
          },
          _enumDomainAccessRuleTypes: enumDomainAccessRuleTypes
        }
      })

      .state('maillayout', {
        abstract: true,
        url: '/maillayout',
        templateUrl: 'ng_components/maillayout/maillayout.html',
        resolve: {
          treeType: function() {
            return 'read';
          },
          authenticatedUser: authenticatedUser,
          defaultDomain: function(authenticatedUser) {
            return authenticatedUser.domain;
          }
        },
        controller: function($scope, $state) {
          $scope.$state = $state;
        }
      })
      .state('maillayout.list', {
        url: '/:domainId/list',
        views: {
          'tree': domainTreeView,
          'list': {
            templateUrl: 'ng_components/maillayout/maillayout_list.tpl.html',
            controller: 'MailLayoutListCtrl',
            resolve: {
              currentDomain: function(Domain, $stateParams, $state, defaultDomain) {
                var domainId = $stateParams.domainId || defaultDomain;
                return Domain.get(domainId);
              },
              mailLayouts: function(MailLayout, currentDomain) {
                return MailLayout.getAll(currentDomain.identifier, true);
              }
            }
          }
        }
      })
      .state('maillayout.detail', {
        url: '/:domainId/detail/:id',
        views: {
          'tree': domainTreeView,
          'detail': {
            templateUrl: 'ng_components/maillayout/maillayout_detail.tpl.html',
            controller: 'MailLayoutDetailCtrl',
            resolve: {
              currentDomain: function(Domain, $stateParams) {
                return Domain.get($stateParams.domainId);
              },
              currentMailLayout: function(MailLayout, $stateParams) {
                return MailLayout.get($stateParams.domainId, $stateParams.id);
              }
            }
          }
        }
      })

      .state('mailcontent', {
        abstract: true,
        url: '/mailcontent',
        templateUrl: 'ng_components/mailcontent/mailcontent.html',
        resolve: {
          treeType: function() {
            return 'read';
          },
          authenticatedUser: authenticatedUser
        },
        controller: function($scope, $state) {
          $scope.$state = $state;
        }
      })
      .state('mailcontent.list', {
        url: '/:domainId/list?language',
        views: {
          'tree': domainTreeView,
          'list': {
            templateUrl: 'ng_components/mailcontent/mailcontent_list.tpl.html',
            controller: 'MailContentListCtrl',
            resolve: {
              currentDomain: function(Domain, $stateParams) {
                return Domain.get($stateParams.domainId);
              },
              mailContents: function(MailContent, currentDomain) {
                return MailContent.getAll(currentDomain.identifier, true);
              }
            }
          }
        }
      })
      .state('mailcontent.detail', {
        url: '/:domainId/detail/:id?language',
        views: {
          'tree': domainTreeView,
          'detail': {
            templateUrl: 'ng_components/mailcontent/mailcontent_detail.tpl.html',
            controller: 'MailContentDetailCtrl',
            resolve: {
              currentDomain: function(Domain, $stateParams) {
                return Domain.get($stateParams.domainId);
              },
              currentMailContent: function(MailContent, $stateParams) {
                return MailContent.get($stateParams.domainId, $stateParams.id);
              }
            }
          }
        }
      })

      .state('mailfooter', {
        abstract: true,
        url: '/mailfooter',
        templateUrl: 'ng_components/mailfooter/mailfooter.html',
        resolve: {
          treeType: function() {
            return 'read';
          },
          authenticatedUser: authenticatedUser
        },
        controller: function($scope, $state) {
          $scope.$state = $state;
        }
      })
      .state('mailfooter.list', {
        url: '/:domainId/list?language',
        views: {
          'tree': domainTreeView,
          'list': {
            templateUrl: 'ng_components/mailfooter/mailfooter_list.tpl.html',
            controller: 'MailFooterListCtrl',
            resolve: {
              currentDomain: function(Domain, $stateParams) {
                return Domain.get($stateParams.domainId);
              },
              mailFooters: function(MailFooter, currentDomain) {
                return MailFooter.getAll(currentDomain.identifier, true);
              }
            }
          }
        }
      })
      .state('mailfooter.detail', {
        url: '/:domainId/detail/:id?language',
        views: {
          'tree': domainTreeView,
          'detail': {
            templateUrl: 'ng_components/mailfooter/mailfooter_detail.tpl.html',
            controller: 'MailFooterDetailCtrl',
            resolve: {
              currentDomain: function(Domain, $stateParams) {
                return Domain.get($stateParams.domainId);
              },
              currentMailFooter: function(MailFooter, $stateParams) {
                return MailFooter.get($stateParams.domainId, $stateParams.id);
              }
            }
          }
        }
      })

      .state('mailconfig', {
        abstract: true,
        url: '/mailconfig',
        templateUrl: 'ng_components/mailconfig/mailconfig.html',
        resolve: {
          treeType: function() {
            return 'read';
          },
          authenticatedUser: authenticatedUser
        },
        controller: function($scope, $state) {
          $scope.$state = $state;
        }
      })
      .state('mailconfig.list', {
        url: '/:domainId/list',
        views: {
          'tree': domainTreeView,
          'list': {
            templateUrl: 'ng_components/mailconfig/mailconfig_list.tpl.html',
            controller: 'MailConfigListCtrl',
            resolve: {
              currentDomain: function(Domain, $stateParams) {
                return Domain.get($stateParams.domainId);
              },
              mailConfigs: function(MailConfig, currentDomain) {
                return MailConfig.getAll(currentDomain.identifier, true);
              }
            }
          }
        }
      })
      .state('mailconfig.detail', {
        url: '/:domainId/detail/:id?language',
        views: {
          'detail': {
            templateUrl: 'ng_components/mailconfig/mailconfig_detail.tpl.html',
            controller: 'MailConfigDetailCtrl',
            resolve: {
              mailLayouts: function(MailLayout, $stateParams) {
                return MailLayout.getAll($stateParams.domainId, false);
              },
              mailFooterLangs: function(MailConfig, $stateParams) {
                return MailConfig.getAllMailFooters($stateParams.id, $stateParams.language);
              },
              currentDomain: function(Domain, $stateParams) {
                return Domain.get($stateParams.domainId);
              },
              currentMailConfig: function(MailConfig, $stateParams) {
                return MailConfig.get($stateParams.domainId, $stateParams.id);
              }
            }
          }
        }
      })
      .state('mailconfig.mailcontentlang', {
        url: '/:domainId/mailcontentlang/:mailConfigId/:id',
        views: {
          'mailcontentlang': {
            templateUrl: 'ng_components/mailcontent/mailcontentlang_detail.tpl.html',
            controller: 'MailContentLangDetailCtrl',
            resolve: {
              currentMailContentLang: function(MailContentLang, $stateParams) {
                return MailContentLang.get($stateParams.id);
              },
              mailContents: function(MailConfig, currentMailContentLang, $stateParams) {
                return MailConfig.getAllMailContents($stateParams.mailConfigId, currentMailContentLang.language, currentMailContentLang.mailContentType);
              }
            }
          }
        }
      })

      .state('password', {
        url: '/password',
        templateUrl: 'ng_components/password/password.html',
        controller: 'PasswordCtrl'
      })

      .state('uploadpropositionfilter', {
        abstract: true,
        url: '/uploadpropositionfilter',
        templateUrl: 'ng_components/uploadpropositionfilter/uploadpropositionfilter.html'
      })
      .state('uploadpropositionfilter.list', {
        url: '/list',
        templateUrl: 'ng_components/uploadpropositionfilter/uploadpropositionfilter_list.tpl.html',
        controller: 'UploadPropositionFilterListCtrl',
        resolve: {
          uploadPropositionFilters: function(UploadPropositionFilter) {
            return UploadPropositionFilter.getAll();
          }
        }
      })
      .state('uploadpropositionfilter.detail', {
        url: '/:id?formState',
        templateUrl: 'ng_components/uploadpropositionfilter/uploadpropositionfilter_detail.tpl.html',
        controller: 'UploadPropositionFilterDetailCtrl',
        resolve: {
          currentUploadPropositionFilter: function($stateParams, UploadPropositionFilter) {
            if ($stateParams.id) {
              return UploadPropositionFilter.get($stateParams.id);
            }
          },
          selectOptions: function(_enumUploadPropositionFieldTypes, _enumUploadPropositionOperatorTypes, _enumUploadPropositionActionTypes, _enumUploadPropositionMatchTypes) {
            return {
              fieldTypes: _enumUploadPropositionFieldTypes,
              operatorTypes: _enumUploadPropositionOperatorTypes,
              actionTypes: _enumUploadPropositionActionTypes,
              matchTypes: _enumUploadPropositionMatchTypes
            };
          },
          _enumUploadPropositionFieldTypes: enumUploadPropositionFieldTypes,
          _enumUploadPropositionOperatorTypes: enumUploadPropositionOperatorTypes,
          _enumUploadPropositionActionTypes: enumUploadPropositionActionTypes,
          _enumUploadPropositionMatchTypes: enumUploadPropositionMatchTypes
        }
      })

      .state('technicalaccount', {
        abstract: true,
        url: '/technicalaccount',
        templateUrl: 'ng_components/technicalaccount/technicalaccount.html'
      })
      .state('technicalaccount.list', {
        url: '/list',
        templateUrl: 'ng_components/technicalaccount/technicalaccount_list.tpl.html',
        controller: 'TechnicalAccountListCtrl',
        resolve: {
          technicalAccounts: function(TechnicalAccount) {
            return TechnicalAccount.getAll();
          }
        }
      })
      .state('technicalaccount.detail', {
        url: '/:id?formState',
        templateUrl: 'ng_components/technicalaccount/technicalaccount_detail.tpl.html',
        controller: 'TechnicalAccountDetailCtrl',
        resolve: {
          currentTechnicalAccount: function($stateParams, TechnicalAccount) {
            if ($stateParams.id) {
              return TechnicalAccount.get($stateParams.id);
            }
          },
          selectOptions: function(_enumTechnicalAccountPermissionTypes) {
            return {
              permissionTypes: _enumTechnicalAccountPermissionTypes
            };
          },
          _enumTechnicalAccountPermissionTypes: enumTechnicalAccountPermissionTypes
        }
      })

      .state('uploadrequest', {
        url: '/uploadrequest',
        abstract: true,
        templateUrl: 'ng_components/uploadrequest/uploadrequest.html'
      })
      .state('uploadrequest.form', {
        url: '/form',
        templateUrl: 'ng_components/uploadrequest/uploadrequest_form.tpl.html',
        controller: 'UploadRequestFormCtrl',
        resolve: {
          uploadRequestStatus: enumUploadRequestStatus
        }
      });
    }
]);

'use strict';

angular.module('linshareAdminApp')
  .factory('Audit', ['$log', 'Restangular',
    function ($log, Restangular) {
      // var self = this;

      // Public API here
      return {
        query: function(criteria) {
          $log.debug('Audit:query');
          return Restangular.all('logs').post(criteria);
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('AuditFormCtrl',
    ['$scope', '$filter', '$log', 'ngTableParams', 'Audit', 'selectOptions', 'authenticatedUser',
    function($scope, $filter, $log, ngTableParams, Audit, selectOptions, authenticatedUser) {
      $scope.criteria = {};
      $scope.actorMails = '';
      $scope.targetMails = '';
      $scope.actorMails = authenticatedUser.mail;
      $scope.allActions = selectOptions.actions;
      $scope.allDomains = selectOptions.domains;
      $scope.opened = {
        from: false,
        to : false
      };

      $scope.open = function(key, $event) {
        $event.preventDefault();
        $event.stopPropagation();
        $scope.opened[key] = true;
      };
      $scope.reloadList = function () {
        $scope.tableParams.reload();
      };
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          actionDate: 'desc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var actorMails = $scope.actorMails.trim();
          if (actorMails) {
            $scope.criteria.actorMails = actorMails.split(',');
          } else {
            $scope.criteria.actorMails = undefined;
          }
          var targetMails = $scope.targetMails.trim();
          if (targetMails) {
            $scope.criteria.targetMails = targetMails.split(',');
          } else {
            $scope.criteria.targetMails = undefined;
          }
          Audit.query($scope.criteria).then(function(logs) {
            var orderedData = params.sorting() ?
                                $filter('orderBy')(logs, params.orderBy()) :
                                logs;
            params.total(orderedData.length);
            $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
          });
        }
      });
    }]
  );

'use strict';

angular.module('linshareAdminApp').directive('lsAlertBox', [
  function() {
    return {
      restrict: 'A',
      scope: false,
      controller: ['$scope',
        function($scope) {
          $scope.alerts = [];
          $scope.$on('pushAlert', function(event, newAlert, message) {
            $scope.alerts.push(newAlert);
            window.scrollTo(0,0);
          });
          $scope.closeAlert = function(index) {
            $scope.alerts.splice(index, 1);
          }
        }
      ],
      templateUrl: 'ng_components/common/alert.tpl.html',
      replace: false
    };
  }
]);

'use strict';

angular.module('linshareAdminApp').directive('lsAlertTimeout', ['$timeout',
  function($timeout) {
    return {
      restrict: 'A',
      scope: false,
      link: function(scope, element, attrs) {
        $timeout(function() {
          element.fadeTo(500, 0).slideUp(500, function(){
            element.children().click();
          });
        }, 4000);
      },
      replace: false
    };
  }
]);

'use strict';

/* Services */

angular.module('linshareAdminApp')
  .factory('Authentication',
    ['$route', '$cookies', '$q', '$log', 'Restangular', 'authService', 'Notification',
    function($route, $cookies, $q, $log, Restangular, authService, Notification) {
      var deferred = $q.defer();
      this.waitingForResponse = false;
      
      var self = this;

      // Do at least one authentication request
      // to handle reload of already connected user
      Restangular.all('authentication').customGET('authorized').then(
        function success(user) {
          deferred.resolve(user);
        }
      );

      // Public API here
      return {
        request: function(login, password, errorCallback) {
          self.waitingForResponse = true;
          $log.debug('Authentication:request');
          return Restangular.all('authentication').customGET('authorized', {
            // QueryParams - Bypass the module authService
            ignoreAuthModule: true
          }, {
            // Headers - Add login password
            Authorization: 'Basic ' + Base64.encode(login + ':' + password)
          }).then(
            function success(user) {
              $log.debug('Connected as ' + user.mail);
              deferred.resolve(user);
              authService.loginConfirmed();
              self.waitingForResponse = false;
            }, function error(response) {
              $log.error(
                [
                 'Authentication:request',
                 'Authentication failed',
                 response.status
                ].join('\n')
              );
              return errorCallback();
            }
          );
        },
        isSuperAdmin: function(user) {
          return user.role === 'SUPERADMIN';
        },
        changePassword: function(password) {
          $log.debug('Authentication:changePassword');
          Restangular.all('authentication').all('change_password').post(password).then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        logout: function() {
          $log.debug('Authentication:logout');
          Restangular.all('authentication').one('logout').get().then(function() {
            delete $cookies.JSESSIONID;
            // Reload authentication modal
            Restangular.all('authentication').customGET('authorized').then(function() {
                deferred.resolve(user);
            });
          });
        },
        isWaitingForResponse: function() {
          return self.waitingForResponse;
        },
        getCurrentUser: function() {
          return deferred.promise;
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('ConfirmDialogCtrl',
    ['$scope', '$log', '$modalInstance', 'content',
      function ($scope, $log, $modalInstance, content) {
        $scope.content = content;
        $scope.validate = function () {
          $modalInstance.close();
        };

        $scope.cancel = function () {
          $modalInstance.dismiss('cancel');
        };
      }
    ]
  );

'use strict';

angular.module('linshareAdminApp')
  .service('Enum', ['$log', 'Restangular', function Enum($log, Restangular) {
    // var self = this;

    return {
      getOptions: function(name) {
        $log.debug('Enum:getOptions:' + name);
        return Restangular.all('enums').all(name).options();
      }
    };
  }]);

'use strict';

angular.module('linshareAdminApp').directive('lsFooter', [
  function() {
    return {
      restrict: 'A',
      transclude: true,
      scope: false,
      templateUrl: 'ng_components/common/footer.tpl.html',
      replace: false
    };
  }
]);

'use strict';

// https://github.com/realcrowd/angularjs-utilities

angular.module('linshareAdminApp').directive('lsFormAttempt', [
  function() {
    return {
      restrict: 'A',
      controller: ['$scope',
        function($scope) {
          this.attempted = false;
          var attemptHandlers = [];
          this.onAttempt = function(handler) {
            attemptHandlers.push(handler);
          };
          this.setAttempted = function() {
            this.attempted = true;
            angular.forEach(attemptHandlers, function(handler) {
              handler();
            });
          };
        }
      ],
      compile: function(cElement, cAttributes, transclude) {
        return {
          pre: function(scope, formElement, attributes, attemptController) {
            scope.ls = scope.ls || {};
            scope.ls[attributes.name] = attemptController;
          },
          post: function(scope, formElement, attributes, attemptController) {
            formElement.bind('submit', function() {
              attemptController.setAttempted();
              if (!scope.$$phase) scope.$apply();
            });
          }
        };
      }
    };
  }
]);

'use strict';

// https://github.com/realcrowd/angularjs-utilities

angular.module('linshareAdminApp').directive('lsFormSubmit', ['$parse',
  function($parse) {
    return {
      restrict: 'A',
      require: 'form',
      link: function(scope, formElement, attributes, formController) {
        var fn = $parse(attributes.lsFormSubmit);
        formElement.bind('submit', function(event) {
          // if form is not valid cancel it.
          if (!formController.$valid) return false;

          scope.$apply(function() {
            fn(scope, {
              $event: event
            });
          });
        });
      }
    };
  }
]);

'use strict';

angular.module('linshareAdminApp')
  .factory('Languages', [ '$log', '$translate', 'Enum', 'Notification',
  function ($log, $translate, Enum, Notification) {
    var languages = {
      'fr': 'FRENCH',
      'en': 'ENGLISH'
    };
        
    return {
  		getCurrentLang: function(){
        var current = $translate.use();
  			if (languages[current])
         return {local: current, filter: languages[current] };
       return {local: 'en', filter: 'ENGLISH'};
  		},
  		langCmp: function(lang){
        var currentLang = {};
        angular.forEach(languages, function(value, key) {
          if (value == lang || key == lang)
          {
            currentLang.filter = value;
            currentLang.local = key;
            return currentLang;
          }
        }, currentLang);
        if (!angular.equals({},currentLang))
          return currentLang;
        Notification.addError({status: 400, errCode: 20000});
        return this.getCurrentLang();
      }
    };
  }
]);
'use strict';

var LoginModalInstanceCtrl =
[ '$scope',
  '$timeout',
  '$modalInstance',
  'Authentication',
  function ($scope, $timeout, $modalInstance, Authentication) {
    // Need this variable to store modal inputs
    // because of Javascript's prototypical inheritance
    $scope.input = {};

    $scope.$on('event:auth-loginRequired', function() {
      $scope.errorLogin = Authentication.isWaitingForResponse();
      $timeout(function() {
        $scope.errorLogin = false;
      }, 2000);
    });

    $scope.submit = function() {
      Authentication.request($scope.input.login, $scope.input.password);
    };

    this.close = function() {
      $modalInstance.close();
    };
  }
];

angular.module('linshareAdminApp').controller('LoginFormCtrl',
['$scope', '$log', '$modal',
  function($scope, $log, $modal) {
    var modalInstance;
    $scope.$on('event:auth-loginRequired', function() {
      $log.debug('event:auth-loginRequired received');
      if (angular.isUndefined(modalInstance)) {
        modalInstance = $modal.open({
          backdrop: 'static',
          controller: LoginModalInstanceCtrl,
          templateUrl: 'ng_components/common/login_form.tpl.html'
        });
      }
    });
    $scope.$on('event:auth-loginConfirmed', function() {
      $log.debug('event:auth-loginConfirmed received');
      if (angular.isDefined(modalInstance)) {
        modalInstance.close();
      }
      modalInstance = undefined;
    });
  }
]);

'use strict';

angular.module('linshareAdminApp')
  .factory('MimeType',
    ['$log', 'Notification', 'Restangular',
    function ($log, Notification, Restangular) {
      // Public API here
      return {
        update: function(mimeType) {
          $log.debug('MimeType:update');
          return Restangular.all('mime_types').customPUT(mimeType);
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp').directive('lsNavbar', [
  function() {
    return {
      restrict: 'A',
      transclude: false,
      scope: false,
      controller: ['$rootScope', '$scope', '$log', '$translate', 'tmhDynamicLocale', 'Authentication',
        function($rootScope, $scope, $log, $translate, tmhDynamicLocale, Authentication) {
          Authentication.getCurrentUser().then(function(user) {
            $scope.userLogged = user;
            $scope.isSuperAdmin = Authentication.isSuperAdmin(user);
          });
          $scope.setLanguage = function(value) {
            $translate.use(value);
          };
          $rootScope.$on('$translateChangeSuccess', function() {
            var lang = $translate.use();
            $log.debug('Language: switched to ' + lang);
            tmhDynamicLocale.set(lang);
          });
          $scope.isCurrentLang = function(value) {
            return $translate.use() === value;
          };
          $scope.logout = function() {
            Authentication.logout();
          }
        }
      ],
      templateUrl: 'ng_components/common/navbar.tpl.html',
      replace: false
    };
  }
]);

'use strict';

/* Services */

angular.module('linshareAdminApp')
  .factory('Notification', ['$rootScope', '$timeout', '$log', 'lsAppConfig',
  function($rootScope, $timeout, $log, lsAppConfig) {
    return {
      addSuccess: function(action) {
        $log.debug('Notification:addSuccess');
        var newAlert = {};
        newAlert.type = 'success';
        newAlert.msg = 'COMMON.NOTIFICATION.SUCCESS.' + action;
        $rootScope.$broadcast('pushAlert', newAlert);
      },
      addError: function(newAlert) {
        $log.debug('Notification:addError');
        if (newAlert.status !== undefined && newAlert.status >= 500 && newAlert.status < 600){
          newAlert.type = 'danger';
          newAlert.errorType = 500;
          newAlert.url = lsAppConfig.backendURL;
          newAlert.msg = 'COMMON.NOTIFICATION.ERROR.' + newAlert.status;
          $rootScope.$broadcast('pushAlert', newAlert);
        }
        else {
          newAlert.type = 'danger';
          newAlert.msg = 'COMMON.NOTIFICATION.ERROR.' + newAlert.errCode;
          $rootScope.$broadcast('pushAlert', newAlert);
        }
      }
    };
  }
]);

'use strict';

angular.module('linshareAdminApp').directive('lsSidebar', [
  function() {
    return {
      restrict: 'A',
      transclude: false,
      scope: false,
      controller: ['$rootScope', '$scope', '$log', '$state', '$translate', 'Authentication', 'Tab', 'Languages',
        function($rootScope, $scope, $log, $state, $translate, Authentication, Tab, Languages) {
          Authentication.getCurrentUser().then(function(user) {
            $scope.tabs = Tab.getAvailableTabs(user);
            $scope.linkActive = false;
            $scope.userDomain = user.domain;
            $rootScope.$on('$stateChangeStart',function(event, toState, toParams){
              $scope.compareCurrentStateToTab(toState.name);
            });
            if ($scope.linkActive == false){
              $scope.compareCurrentStateToTab($state.next.name);
            }
          });
          $scope.$watch('search', function(newValue) {
            var inSearch = !_.isEmpty(newValue);
            angular.forEach($scope.tabs, function(value) {
              value.isopen = inSearch;
            })
          });
          $scope.language = Languages.getCurrentLang().filter;
          $scope.compareCurrentStateToTab = function(currentState) {
            angular.forEach($scope.tabs, function(value) {
              angular.forEach(value.links, function(link) {

                if (currentState == link.sref) {
                  $scope.setActiveSection(link.sref, value);

                } else if (link.children_sref) {

                  angular.forEach(link.children_sref, function(subLink) {
                    if (currentState == link.sref || currentState == subLink)
                      $scope.setActiveSection(link.sref, value);
                  });
                }
              })
            });
          };
          $scope.setActiveSection = function(link, value) {
            $scope.linkActive = link;
            value.isopen = true;
          };
        }
      ],
      templateUrl: 'ng_components/common/sidebar.tpl.html',
      replace: false
    };
  }
]);


'use strict';

angular.module('linshareAdminApp')
  .factory('Tab',
    ['$log', 'Authentication',
    function($log, Authentication) {
      var domains = {
        name: 'COMMON.TAB.DOMAINS',
        icon: 'fa-cloud',
        superAdminOnly: true,
        links: [
          {
            name: 'COMMON.TAB.LDAP_CONNECTIONS',
            sref: 'ldapconnection.list',
            children_sref: [
              'ldapconnection.detail'
            ]
          }, {
            name: 'COMMON.TAB.DOMAIN_PATTERNS',
            sref: 'domainpattern.list',
            children_sref: [
              'domainpattern.detail'
            ]
          }, {
            name: 'COMMON.TAB.MANAGE_DOMAINS',
            sref: 'domain.detail'
          }, {
            name: 'COMMON.TAB.DOMAIN_ORDER',
            sref: 'domain.order'
          }, {
            name: 'COMMON.TAB.DOMAIN_POLICIES',
            sref: 'domainpolicy.list',
            children_sref: [
              'domainpolicy.detail'
            ]
          }
        ]
      };

      var mails = {
        name: 'COMMON.TAB.MAILS',
        icon: 'fa-envelope',
        superAdminOnly: true,
        links: [
          {
            name: 'COMMON.TAB.MAIL_LAYOUT',
            sref: 'maillayout.list',
            children_sref: [
              'maillayout.detail'
            ]
          }, {
            name: 'COMMON.TAB.MAIL_FOOTER',
            sref: 'mailfooter.list',
            children_sref: [
              'mailfooter.detail'
            ]
          }, {
            name: 'COMMON.TAB.MAIL_CONTENT',
            sref: 'mailcontent.list',
            children_sref: [
              'mailcontent.detail'
            ]
          }, {
            name: 'COMMON.TAB.MAIL_CONFIG',
            sref: 'mailconfig.list',
            children_sref: [
              'mailconfig.detail'
            ]
          }
        ]
      };

      var parameters = {
        name: 'COMMON.TAB.PARAMETERS',
        icon: 'fa-gears',
        superAdminOnly: false,
        links: [
          {
            name: 'COMMON.TAB.FUNCTIONALITIES',
            superAdminOnly: false,
            sref: 'functionality.list',
            children_sref: [
              'functionality.detail'
            ]
          }, {
            name: 'COMMON.TAB.MIME_POLICIES',
            superAdminOnly: true,
            sref: 'mimepolicy.list',
            children_sref: [
              'mimepolicy.detail'
            ]
          }, {
            name: 'COMMON.TAB.UPLOAD_PROPOSITION_FILTER',
            superAdminOnly: true,
            sref: 'uploadpropositionfilter.list',
            children_sref: [
              'uploadpropositionfilter.detail',
            ]
          }
        ]
      };

      var users = {
        name: 'COMMON.TAB.USERS',
        icon: 'fa-users',
        superAdminOnly: false,
        links: [
          {
            name: 'COMMON.TAB.MANAGE_USERS',
            superAdminOnly: false,
            sref: 'user.list',
            children_sref: [
              'user.detail'
            ]
          }, {
            name: 'COMMON.TAB.INCONSISTENT_USERS',
            superAdminOnly: true,
            sref: 'inconsistentuser.list',
            children_sref: [
              'inconsistentuser.detail'
            ]
          }, {
            name: 'COMMON.TAB.THREADS',
            superAdminOnly: true,
            sref: 'thread.list',
            children_sref: [
              'thread.detail'
            ]
          }, {
            name: 'COMMON.TAB.MAILING_LISTS',
            superAdminOnly: true,
            sref: 'mailinglist.list',
            children_sref: [
              'mailinglist.detail'
            ]
          }, {
            name: 'COMMON.TAB.TECHNICAL_ACCOUNT',
            superAdminOnly: true,
            sref: 'technicalaccount.list',
            children_sref: [
              'technicalaccount.detail'
            ]
          }
        ]
      };

      var history = {
        name: 'COMMON.TAB.HISTORY',
        icon: 'fa-archive',
        superAdminOnly: false,
        links: [
          {
            name: 'COMMON.TAB.AUDIT',
            superAdminOnly: false,
            sref: 'audit.form'
          }, {
            name: 'COMMON.TAB.UPLOAD_REQUEST',
            superAdminOnly: true,
            sref: 'uploadrequest.form'
          }
        ]
      };

      this.tabs = [parameters, users, history, domains, mails];

      var self = this;

      // Public API here
      return {
        getAvailableTabs: function(user) {
          $log.debug('Tab:getAvailableTabs');
          var tabs = self.tabs;
          if (!Authentication.isSuperAdmin(user)) {
            tabs = _.filter(tabs, function(container) {
              return container.superAdminOnly === false;
            });

            _.forEach(tabs, function(container) {
              container.links = _.filter(container.links, function(link) {
                return link.superAdminOnly === false;
              });
            });
          }
          return tabs;
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .factory('Domain',
    ['$q', '$log', 'Notification', 'Restangular',
    function ($q, $log, Notification, Restangular) {
      // var self = this;

      /**
       * As domains are returned as tree,
       * we need to put restangular route manually in all domains
       */
      function restangularizeTree(domain, route) {
        Restangular.restangularizeElement(null, domain, route);
        if (!_.isEmpty(domain.children)) {
          angular.forEach(domain.children, function(child) {
            restangularizeTree(child, route);
          });
        }
      }

      // Public API here
      return {
        getDomainTree: function(domainId) {
          $log.debug('Domain:getDomainTree');
          return Restangular.all('domains').one(domainId).get({tree: true}).then(function(rootDomain) {
            restangularizeTree(rootDomain, 'domains');
            var dfd = $q.defer();
            dfd.resolve(rootDomain);
            return dfd.promise;
          });
        },
        getAll: function() {
          $log.debug('Domain:getAll');
          return Restangular.all('domains').getList();
        },
        get: function(id) {
          $log.debug('Domain:get');
          return Restangular.one('domains', id).get({tree: true});
        },
        add: function(domain) {
          $log.debug('Domain:add');
          return Restangular.all('domains').post(domain).then(function() {
            Notification.addSuccess('CREATE');
          });
        },
        update: function(domain, notify) {
          $log.debug('Domain:update');
          notify = typeof notify !== 'undefined' ? notify : true;
          delete domain.children;
          return domain.put().then(function() {
            if (notify) {
              Notification.addSuccess('UPDATE');
            }
          });
        },
        remove: function(domain) {
          $log.debug('Domain:remove');
          return domain.remove().then(function() {
            Notification.addSuccess('DELETE');
          });
        },
        createSample: function (parentId, type) {
          var sample = {};
          sample.parent = parentId;
          sample.type = type;
          sample.providers = [];
          if(type === 'GUESTDOMAIN') {
            sample.userRole = 'SIMPLE';
          }
          return sample;
        },
        getId: function(domain) {
          return domain.identifier;
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('DomainDetailCtrl',
    ['$scope', '$log', '$modal', '$state', 'selectOptions', 'currentDomain', 'authenticatedUser', 'Domain',
    function($scope, $log, $modal, $state, selectOptions, currentDomain, authenticatedUser, Domain) {
      if (currentDomain) {
        $scope.ldapConnections = selectOptions.ldapConnectionIds;
        $scope.domainPatterns = selectOptions.domainPatternIds;
        $scope.domainPolicies = selectOptions.domainPolicyIds;
        $scope.mailConfigs = selectOptions.mailConfigs;
        $scope.mimePolicies = selectOptions.mimePolicies;
        $scope.userRoles = selectOptions.userRoles;
        $scope.languages = selectOptions.languages;
        $scope.state = $state.params.formState;
        if ($scope.state === 'create') {
          currentDomain = Domain.createSample(currentDomain.identifier, $state.params.domainType);
        }
        $scope.domain = currentDomain;
        $scope.isSuperAdmin = authenticatedUser.role === 'SUPERADMIN';
        $scope.isRootDomain = currentDomain.type === 'ROOTDOMAIN';
        $scope.disableProvider = ($scope.isRootDomain || currentDomain.providers.length != 0);
      }

      $scope.addProvider = function() {
        if (!$scope.disableProvider) {
          $scope.domain.providers.push({
            ldapConnectionId: '',
            domainPatternId: '',
            baseDn: ''
          });
          $scope.disableProvider = true;
        } else {
          $log.error('Try to add more than one provider');
        }
      };
      $scope.deleteProvider = function() {
        if ($scope.disableProvider) {
          $scope.domain.providers.splice(0, 1);
          $scope.disableProvider = false;
        } else {
          $log.error('Try to delete an non existing provider');
        }
      }
      $scope.submit = function() {
        if ($scope.state === 'edit') {
          Domain.update($scope.domain).then(function() {
            $scope.cancel();
          });
        } else if ($scope.state === 'create') {
          Domain.add($scope.domain).then(function() {
            $scope.cancel();
          });
        } else {
          $log.error('Invalid state');
        }
      };
      $scope.remove = function() {
        if ($scope.state === 'edit') {
          var modalInstance = $modal.open({
            templateUrl: 'ng_components/common/confirm_modal.tpl.html',
            controller: 'ConfirmDialogCtrl',
            resolve: {
              content: function() {
                return 'MANAGE_DOMAINS.CONFIRM_DELETE_FORM.PARAGRAPH';
              }
            }
          });
          modalInstance.result.then(
            function validate() {
              Domain.remove($scope.domain).then(function() {
                $scope.cancel();
              });
            }, function cancel() {
              $log.debug('Deletion modal dismissed');
            }
          );
        } else {
          $log.error('Invalid state');
        }
      };
      $scope.reset = function() {
        $state.reinit();
      };
      $scope.cancel = function() {
        $state.go('domain.detail', {domainId: null, formState: null, domainType: null}, {reload: true});
      };
    }]
  )

'use strict';

angular.module('linshareAdminApp')
  .controller('DomainOrderCtrl',
    ['$scope', '$filter', '$log', 'ngTableParams', 'Domain', 'domains',
    function($scope, $filter, $log, ngTableParams, Domain, domains) {
      $scope.swap = function(x, y, data) {
        data[x].authShowOrder = y;
        data[y].authShowOrder = x;
        Domain.update(data[x], false).then(function() { // Disable one notify
          Domain.update(data[y]).then(function() {
            $scope.reloadList();
          });
        });
      };
      $scope.reloadList = function () {
        $scope.tableParams.reload();
      };
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          authShowOrder: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var orderedData = params.sorting() ?
                              $filter('orderBy')(domains, params.orderBy()) :
                              domains;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );

'use strict';

angular.module('linshareAdminApp')
  .controller('DomainTreeCtrl',
    ['$scope', '$log', 'treeType', 'rootDomain',
    function($scope, $log, treeType, rootDomain) {
      $scope.root = [rootDomain];
      $scope.state = treeType;

      $scope.hasGuestDomain = function(topDomain) {
        return !_.isEmpty(
          _.find(topDomain.children, {
            'type': 'GUESTDOMAIN'
          })
        );
      };
      $scope.canAddChildDomain = function(domain) {
        return $scope.state === 'edit' && 
          (domain.type === 'TOPDOMAIN' || domain.type === 'ROOTDOMAIN');
      };
      $scope.canAddTopDomain = function(domain) {
        return domain.type === 'ROOTDOMAIN';
      };
      $scope.canAddSubDomain = function(domain) {
        return domain.type === 'TOPDOMAIN';
      };
      $scope.canAddGuestDomain = function(domain) {
        return (domain.type === 'TOPDOMAIN' &&
          _.isEmpty(
            _.find(domain.children, {
              'type': 'GUESTDOMAIN'
            })
          )
        );
      };
    }]
  );

'use strict';

angular.module('linshareAdminApp')
  .factory('DomainPattern', ['$q', '$log', 'Restangular', 'Notification',
    function ($q, $log, Restangular, Notification) {
      //var self = this;

      // Public API here
      return {
        getAll: function() {
          $log.debug('DomainPattern:getAll');
          return Restangular.all('domain_patterns').getList();
        },
        get: function(id) {
          $log.debug('DomainPattern:get');
          return Restangular.one('domain_patterns', id).get();
        },
        add: function(domainPattern) {
          $log.debug('DomainPattern:add');
          return Restangular.all('domain_patterns').post(domainPattern).then(function() {
            Notification.addSuccess('CREATE');
          });
        },
        update: function(domainPattern) {
          $log.debug('DomainPattern:update');
          return domainPattern.put().then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        remove: function(domainPattern) {
          $log.debug('DomainPattern:remove');
          return domainPattern.remove().then(function() {
            Notification.addSuccess('DELETE');
          });
        },
        getAllModels: function() {
          $log.debug('DomainPattern:getAllModels');
          return Restangular.all('domain_patterns').all('models').getList();
        },
        copyFromModel: function(model) {
          var copy = Restangular.copy(model);
          copy.identifier = '';
          return copy;
        },
        getEmptyModel: function() {
          return {identifier: ''};
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('DomainPatternDetailCtrl',
    ['$scope', '$state', '$modal', '$log', 'DomainPattern', 'models', 'currentDomainPattern',
    function($scope, $state, $modal, $log, DomainPattern, models, currentDomainPattern) {
      $scope.state = $state.params.formState;
      $scope.domainPattern = currentDomainPattern || {};
      if ($scope.state === 'create') {
        var emptyModel = DomainPattern.getEmptyModel();
        $scope.models = models;
        $scope.models.push(emptyModel);
        $scope.modelSelector = emptyModel;
        $scope.$watch('modelSelector', function() {
          loadModel();
        });
      } 

      $scope.submit = function() {
        if ($scope.state === 'edit') {
          DomainPattern.update($scope.domainPattern).then(function() {
            $scope.cancel();
          });
        } else if ($scope.state === 'create') {
          DomainPattern.add($scope.domainPattern).then(function() {
            $scope.cancel();
          });
        } else {
          $log.error('Invalid state');
        }
      };
      $scope.remove = function() {
        if ($scope.state === 'edit') {
          var modalInstance = $modal.open({
            templateUrl: 'ng_components/common/confirm_modal.tpl.html',
            controller: 'ConfirmDialogCtrl',
            resolve: {
              content: function() {
                return 'DOMAIN_PATTERNS.CONFIRM_DELETE_FORM.PARAGRAPH';
              }
            }
          });
          modalInstance.result.then(
            function validate() {
              DomainPattern.remove($scope.domainPattern).then(function() {
                $scope.cancel();
              });
            }, function cancel() {
              $log.debug('Deletion modal dismissed');
            }
          );
        } else {
          $log.error('Invalid state');
        }
      };
      $scope.cancel = function() {
        $state.go("domainpattern.list");
      };
      $scope.reset = function() {
        $state.reinit();
      };
      function loadModel() {
        $scope.domainPattern = DomainPattern.copyFromModel($scope.modelSelector);
      };
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('DomainPatternListCtrl',
    ['$scope', '$filter', '$log', 'ngTableParams', 'domainPatterns',
    function($scope, $filter, $log, ngTableParams, domainPatterns) {

      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          identifier: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var orderedData = params.sorting() ?
                              $filter('orderBy')(domainPatterns, params.orderBy()) :
                              domainPatterns;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );

'use strict';

angular.module('linshareAdminApp')
  .factory('DomainPolicy', ['$log', 'Restangular', 'Notification',
    function ($log, Restangular, Notification) {
      //var self = this;

      // Public API here
      return {
        getAll: function() {
          $log.debug('DomainPolicy:getAll');
          return Restangular.all('domain_policies').getList();
        },
        get: function(id) {
          $log.debug('DomainPolicy:get');
          return Restangular.one('domain_policies', id).get();
        },
        add: function(domainPolicy) {
          $log.debug('DomainPolicy:add');
          return Restangular.all('domain_policies').post(domainPolicy).then(function() {
            Notification.addSuccess('CREATE');
          });
        },
        update: function(domainPolicy) {
          $log.debug('DomainPolicy:update');
          return domainPolicy.put().then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        remove: function(domainPolicy) {
          $log.debug('DomainPolicy:remove');
          return domainPolicy.remove().then(function() {
            Notification.addSuccess('DELETE');
          });
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('DomainPolicyDetailCtrl',
    ['$scope', '$filter', '$modal', '$log', '$state', 'ngTableParams', 'DomainPolicy', 'selectOptions', 'currentDomainPolicy',
    function($scope, $filter, $modal, $log, $state, ngTableParams, DomainPolicy, selectOptions, currentDomainPolicy) {
      $scope.allDomains = selectOptions.domains;
      $scope.allRuleTypes = selectOptions.domainAccessRuleTypes;
      $scope.state = $state.params.formState;
      $scope.domainPolicy = currentDomainPolicy || {};
      if ($scope.state === 'create') {
        $scope.domainPolicy.accessPolicy = {
          'rules': []
        };
      }

      $scope.submit = function() {
        if ($scope.state === 'edit') {
          DomainPolicy.update($scope.domainPolicy).then(function() {
            $scope.cancel();
          });
        } else if ($scope.state === 'create') {
          DomainPolicy.add($scope.domainPolicy).then(function() {
            $scope.cancel();
          });
        } else {
          $log.error('Invalid state');
        }
      };
      $scope.remove = function() {
        if ($scope.state === 'edit') {
          var modalInstance = $modal.open({
            templateUrl: 'ng_components/common/confirm_modal.tpl.html',
            controller: 'ConfirmDialogCtrl',
            resolve: {
              content: function() {
                return 'DOMAIN_POLICIES.CONFIRM_DELETE_FORM.PARAGRAPH';
              }
            }
          });
          modalInstance.result.then(
            function validate() {
              DomainPolicy.remove($scope.domainPolicy).then(function() {
                $scope.cancel();
              });
            }, function cancel() {
              $log.debug('Deletion modal dismissed');
            }
          );
        } else {
          $log.error('Invalid state');
        }
      };
      $scope.cancel = function() {
        $state.go('domainpolicy.list');
      };
      $scope.reset = function() {
        $state.reinit();
      };
      $scope.addRule = function(ruleToAdd) {
        if (ruleToAdd.type === 'ALLOW_ALL' || ruleToAdd.type === 'DENY_ALL') {
          delete ruleToAdd.domain;
        }
        $scope.domainPolicy.accessPolicy.rules.push(angular.copy(ruleToAdd));
        $scope.reloadList();
      };
      $scope.deleteRule = function(index) {
        $scope.domainPolicy.accessPolicy.rules.splice(index, 1);
        $scope.reloadList();
      };
      $scope.swap = function(x, y) {
        var rules = $scope.domainPolicy.accessPolicy.rules;
        // Only Y could be out of range
        y = y % rules.length;
        // Swap values
        rules[x] = rules.splice(y, 1, rules[x])[0];
        $scope.reloadList();
      };
      $scope.reloadList = function () {
        $scope.tableParams.reload();
      };
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10      // count per page
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var orderedData = params.sorting() ?
                              $filter('orderBy')($scope.domainPolicy.accessPolicy.rules, params.orderBy()) :
                              $scope.domainPolicy.accessPolicy.rules;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('DomainPolicyListCtrl',
    ['$scope', '$filter', '$log', 'ngTableParams', 'domainPolicies',
    function($scope, $filter, $log, ngTableParams, domainPolicies) {

      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          identifier: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var orderedData = params.sorting() ?
                              $filter('orderBy')(domainPolicies, params.orderBy()) :
                              domainPolicies;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .factory('Functionality',
    ['$log', '$translate', 'Notification', 'Restangular',
    function ($log, $translate, Notification, Restangular) {
      //var self = this;

      // Public API here
      return {
        getAll: function(domainId) {
          $log.debug('Functionality:getAll');
          return Restangular.all('functionalities').getList({domainId: domainId});
        },
        get: function(domainId, funcId) {
          $log.debug('Functionality:get');
          return Restangular.one('functionalities', funcId).get({domainId: domainId});
        },
        update: function(functionality) {
          $log.debug('Functionality:update');
          return functionality.put();
        },
        remove: function(functionality) {
          $log.debug('Functionality:remove');
          return functionality.remove();
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('FunctionalityDetailCtrl',
    ['$scope', '$timeout', '$log', '$state', 'Functionality', 'currentDomain', 'currentFunctionality',
    function($scope, $timeout, $log, $state, Functionality, currentDomain, currentFunctionality) {
        $scope.functionality = currentFunctionality;
        $scope.domain = currentDomain;
        $scope.iconSaved = false;
        var timeoutId = undefined;
        var updateStatus = function(policyType) {
          if (policyType) {
            policyType.status = policyType.policy === 'ALLOWED' ? policyType.status : policyType.policy === 'MANDATORY';
          }
        };

        $scope.showActivation = function(functionality) {
          return functionality.activationPolicy.parentAllowUpdate;
        };
        $scope.showConfiguration = function(functionality) {
          return functionality.activationPolicy.policy != 'FORBIDDEN' 
                  && functionality.configurationPolicy.parentAllowUpdate;
        };
        $scope.showDelegation = function(functionality) {
          return functionality.activationPolicy.policy != 'FORBIDDEN' 
                  && functionality.delegationPolicy
                  && functionality.delegationPolicy.parentAllowUpdate;
        };
        $scope.showParameters = function(functionality) {
          return functionality.parentAllowParametersUpdate;
        };
        $scope.disableStatus = function(policyType) {
          if (policyType) {
            return policyType.policy !== 'ALLOWED';
          }
          return false;
        };
        $scope.checkPolicyType = function (policyType) {
          policyType.status = policyType.defaultStatus;
        };
        $scope.isRootDomain = function() {
          return $scope.functionality.domain === 'LinShareRootDomain';
        };
        $scope.displayIconSaved = function() {
          $scope.iconSaved = true;
          $timeout(function() {
            $scope.iconSaved = false;
          }, 800);
        };
        $scope.updateWithTimeout = function() {
          if (angular.isDefined(timeoutId)) {
            $timeout.cancel(timeoutId);
          }
          timeoutId = $timeout(function() {
            $scope.update();
            timeoutId = undefined;
          }, 1500);
        };
        $scope.update = function() {
          updateStatus($scope.functionality.activationPolicy);
          updateStatus($scope.functionality.configurationPolicy);
          updateStatus($scope.functionality.delegationPolicy);
          Functionality.update($scope.functionality).then(function() {
            $scope.displayIconSaved();
          });
        };
        $scope.resetToParent = function() {
          Functionality.remove($scope.functionality).then(function() {
            $state.reinit();
            $scope.displayIconSaved();
          });
        };
        $scope.cancel = function() {
          $state.go('functionality.list', {domainId: $scope.functionality.domain});
        };
    }]
  );

'use strict';

angular.module('linshareAdminApp')
  .controller('FunctionalityListCtrl',
    ['$scope', '$filter', '$q', '$translate', '$state', 'ngTableParams', 'functionalities', 'currentDomain',
    function($scope, $filter, $q, $translate, $state, ngTableParams, functionalities, currentDomain) {
      $scope.domain = currentDomain;

      $scope.showFunctionality = function(functionality) {
        return functionality.activationPolicy.parentAllowUpdate
              || functionality.configurationPolicy.parentAllowUpdate;
      };
      $scope.isActivated = function(functionality) {
        return functionality.activationPolicy.status;
      };
      $scope.localizedName = function(column) {
        var def = $q.defer();
        var names = [];

        def.resolve(names);
        return def;
      };
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          localizedName: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var displayableFuncs = _.where(functionalities, {'displayable': true});
          var nameFilter = params.filter().localizedName;
          var deferred = $q.defer();

          if (!_.isEmpty(nameFilter)) {
            var ids = _.pluck(displayableFuncs, 'identifier');
            var localizedNames = _.map(ids, function(id) { return 'FUNCTIONALITIES.NAME.' + id });
            $translate(localizedNames).then(
              function(translations) {
                deferred.resolve(_.filter(displayableFuncs, function(f) {
                  return translations['FUNCTIONALITIES.NAME.' + f.identifier].toLowerCase().indexOf(nameFilter.toLowerCase()) != -1;
                }));
              }
            );
            deferred.promise.then(function(data) {
              var orderedData = params.sorting() ?
                        $filter('orderBy')(data, params.orderBy()) :
                        data;
              params.total(orderedData.length);
              $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
            });
          } else {
            var orderedData = params.sorting() ?
                      $filter('orderBy')(displayableFuncs, params.orderBy()) :
                      directive;
            params.total(orderedData.length);
            $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
          }
        }
      });
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('InconsistentUserDetailCtrl',
    ['$scope', '$modal', '$log', '$state', 'User', 'allDomains', 'currentUser',
    function($scope, $modal, $log, $state, User, allDomains, currentUser) {
      $scope.allDomains = allDomains;
      $scope.user = currentUser;

      $scope.cancel = function() {
        $state.go('inconsistentuser.list'); 
      };
      $scope.delete = function(user) {
        var modalInstance = $modal.open({
          templateUrl: 'ng_components/common/confirm_modal.tpl.html',
          controller: 'ConfirmDialogCtrl',
          resolve: {
            content: function() {
              return 'INCONSISTENT_USERS.CONFIRM_DELETE_FORM.PARAGRAPH';
            }
          }
        });
        modalInstance.result.then(
          function validate() {
            User.remove($scope.user).then(function() {
              $scope.cancel();
            });
          }, function cancel() {
            $log.debug('Deletion modal dismissed');
          }
        );
      };
      $scope.submit = function(user, domain) {
        user.domain = domain;
        User.update($scope.user).then(function() {
          $scope.cancel();
        });
      };
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('InconsistentUserListCtrl',
    ['$scope', '$filter', '$log', 'ngTableParams', 'allInconsistents',
    function($scope, $filter, $log, ngTableParams, allInconsistents) {
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          lastName: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          allInconsistents = params.sorting() ?
                              $filter('orderBy')(allInconsistents, params.orderBy()) :
                              allInconsistents;
          params.total(allInconsistents.length);
          $defer.resolve(allInconsistents.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );

'use strict';

angular.module('linshareAdminApp')
  .factory('LdapConnection', ['$log', 'Restangular', 'Notification',
    function ($log, Restangular, Notification) {
      var self = this;

      // Public API here
      return {
        getAll: function() {
          $log.debug('LdapConnection:getAll');
          return Restangular.all('ldap_connections').getList();
        },
        get: function(id) {
          $log.debug('LdapConnection:get');
          return Restangular.one('ldap_connections', id).get();
        },
        add: function(ldapConnection) {
          $log.debug('LdapConnection:add');
          return Restangular.all('ldap_connections').post(ldapConnection).then(function() {
            Notification.addSuccess('CREATE');
          });
        },
        update: function(ldapConnection) {
          $log.debug('LdapConnection:update');
          return ldapConnection.put().then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        remove: function(ldapConnection) {
          $log.debug('LdapConnection:remove');
          return ldapConnection.remove().then(function() {
              Notification.addSuccess('DELETE');
          });
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('LdapConnectionDetailCtrl',
    ['$scope', '$state', '$modal', '$log', 'LdapConnection', 'currentLdapConnection',
    function($scope, $state, $modal, $log, LdapConnection, currentLdapConnection) {
      $scope.state = $state.params.formState;
      $scope.ldapConnection = currentLdapConnection || {};

      $scope.submit = function() {
        if ($scope.state === 'edit') {
          LdapConnection.update($scope.ldapConnection).then(function() {
            $scope.cancel();
          });
        } else if ($scope.state === 'create') {
          LdapConnection.add($scope.ldapConnection).then(function() {
              $scope.cancel();
          });
        } else {
          $log.error('Invalid state');
        }
      };
      $scope.remove = function() {
        if ($scope.state === 'edit') {
          var modalInstance = $modal.open({
            templateUrl: 'ng_components/common/confirm_modal.tpl.html',
            controller: 'ConfirmDialogCtrl',
            resolve: {
              content: function() {
                return 'DOMAIN_PATTERNS.CONFIRM_DELETE_FORM.PARAGRAPH';
              }
            }
          });
          modalInstance.result.then(
            function validate() {
              LdapConnection.remove($scope.ldapConnection).then(function() {
                $scope.cancel();
              });
            }, function cancel() {
              $log.debug('Deletion modal dismissed');
            }
          );
        } else {
          $log.error('Invalid state');
        }
      };
      $scope.cancel = function() {
        $state.go('ldapconnection.list');
      };
      $scope.reset = function() {
        $state.reinit();
      };
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('LdapConnectionListCtrl',
    ['$scope', '$filter', '$log', 'ngTableParams', 'ldapConnections',
    function($scope, $filter, $log, ngTableParams, ldapConnections){

      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          identifier: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var orderedData = params.sorting() ?
                              $filter('orderBy')(ldapConnections, params.orderBy()) :
                              ldapConnections;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .factory('MailConfig',
    ['$log', 'Notification', 'Restangular',
    function ($log, Notification, Restangular) {
      //var self = this;

      // Public API here
      return {
        getAll: function(domainId, onlyCurrentDomain) {
          $log.debug('MailConfig:getAll');
          return Restangular.all('mail_configs')
            .getList({domainId: domainId, onlyCurrentDomain: onlyCurrentDomain});
        },
        getAllMailContents: function(mailConfigUuid, language, mailContentType) {
          $log.debug('MailConfig:getAllMailContents');
          return Restangular.one('mail_configs', mailConfigUuid)
            .getList('mail_contents', {language: language, mailContentType: mailContentType});
        },
        getAllMailFooters: function(mailConfigUuid, language) {
          $log.debug('MailConfig:getAllMailFooters');
          return Restangular.one('mail_configs', mailConfigUuid)
            .getList('mail_footers', {language: language});
        },
        get: function(domainId, mailConfigId) {
          $log.debug('MailConfig:get');
          return Restangular.one('mail_configs', mailConfigId)
            .get({domainId: domainId});
        },
        add: function(mailConfig) {
          $log.debug('MailConfig:add');
          return Restangular.all('mail_configs').post(mailConfig).then(function() {
            Notification.addSuccess('CREATE');
          });
        },
        update: function(mailConfig) {
          $log.debug('MailConfig:update');
          return mailConfig.put().then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        remove: function(mailConfig) {
          $log.debug('MailConfig:remove');
          return mailConfig.remove().then(function() {
            Notification.addSuccess('DELETE');
          });
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('MailConfigDetailCtrl',
    ['$scope', '$filter', '$log', '$modal',  '$state', 'ngTableParams', 'MailConfig', 'currentDomain', 'currentMailConfig', 'mailLayouts', 'mailFooterLangs',
    function($scope, $filter, $log, $modal, $state, ngTableParams, MailConfig, currentDomain, currentMailConfig, mailLayouts, mailFooterLangs) {
      $scope.domain = currentDomain;
      $scope.mailConfig = currentMailConfig;
      $scope.mailLayouts = mailLayouts;
      $scope.mailFooterLangs = mailFooterLangs;

      $scope.remove = function() {
        var modalInstance = $modal.open({
          templateUrl: 'ng_components/common/confirm_modal.tpl.html',
          controller: 'ConfirmDialogCtrl',
          resolve: {
            content: function() {
              return 'MAIL_CONFIG.CONFIRM_DELETE_FORM.PARAGRAPH';
            }
          }
        });
        modalInstance.result.then(
          function validate() {
            MailConfig.remove($scope.mailConfig).then(function() {
              $scope.cancel();
            });
          }, function cancel() {
            $log.debug('Deletion modal dismissed');
          }
        );
      };
      $scope.update = function(redirect) {
        MailConfig.update($scope.mailConfig).then(function() {
          if (redirect) {
            $scope.cancel();
          }
        });
      };
      $scope.cancel = function() {
        $state.go("mailconfig.list", {domainId: $state.params.domainId});
      };
      $scope.reset = function() {
        $state.reinit();
      };
      $scope.editMailContentLang = function(mailContentLang) {
        $state.go('mailconfig.detail', {domainId: $state.params.domainId, contentLangId: mailContentLang.uuid});
      };
      $scope.updateMailFooterLang = function(mailFooterLang) {
        MailFooterLang.update(mailFooterLang)
      };
      $scope.filters = {
        language: $state.params.language
      };
      $scope.$watch('filters.language',
        function(newValue) {
          $state.go('.', {domainId: $state.params.domainId, language: newValue});
        }
      );
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        filter: $scope.filters,
        sorting: {
          mailContentName: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var filteredData = params.filter() ?
                    $filter('filter')($scope.mailConfig.mailContentLangs, params.filter()) :
                    $scope.mailConfig.mailContentLangs;
          var orderedData = params.sorting() ?
                    $filter('orderBy')(filteredData, params.orderBy()) :
                    filteredData;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('MailConfigListCtrl',
    ['$scope', '$filter', '$log', '$modal', 'ngTableParams', 'mailConfigs', 'currentDomain',
    function($scope, $filter, $log, $modal, ngTableParams, mailConfigs, currentDomain) {
      $scope.domain = currentDomain;

      $scope.add = function() {
        var modalInstance = $modal.open({
          controller: 'mailConfigModalCtrl',
          templateUrl: 'ng_components/mailconfig/mailconfig_modal.tpl.html'
        });
      };
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          name: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var orderedData = params.sorting() ?
                    $filter('orderBy')(mailConfigs, params.orderBy()) :
                    mailConfigs;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('mailConfigModalCtrl',
    ['$scope', '$log', '$state', '$modalInstance', 'MailConfig',
      function ($scope, $log, $state, $modalInstance, MailConfig) {
        $scope.create = function () {
          MailConfig.add($scope.mailConfig).then(function() {
            $modalInstance.close();
            $scope.reset();
            $state.reinit();
          });
        };
        $scope.cancel = function () {
          $modalInstance.dismiss('cancel');
          $scope.reset();
        };
        $scope.reset = function() {
          $scope.mailConfig = {
            visible: false,
            domain: $state.params.domainId
          };
        };
        $scope.reset();
      }
    ]
  );

'use strict';

angular.module('linshareAdminApp')
  .factory('MailContent',
    ['$log', 'Notification', 'Restangular',
    function ($log, Notification, Restangular) {
      //var self = this;

      // Public API here
      return {
        getAll: function(domainId, onlyCurrentDomain) {
          $log.debug('MailContent:getAll');
          return Restangular.all('mail_contents').getList({domainId: domainId, onlyCurrentDomain: onlyCurrentDomain});
        },
        get: function(domainId, mailContentId) {
          $log.debug('MailContent:get');
          return Restangular.one('mail_contents', mailContentId).get({domainId: domainId});
        },
        add: function(mailContent) {
          $log.debug('MailContent:add');
          return Restangular.all('mail_contents').post(mailContent).then(function() {
            Notification.addSuccess('CREATE');
          });
        },
        update: function(mailContent) {
          $log.debug('MailContent:update');
          return mailContent.put().then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        remove: function(mailContent) {
          $log.debug('MailContent:remove');
          return mailContent.remove().then(function() {
            Notification.addSuccess('DELETE');
          });
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('MailContentDetailCtrl',
    ['$scope', '$log', '$modal',  '$state', 'MailContent', 'currentDomain', 'currentMailContent',
    function($scope, $log, $modal, $state, MailContent, currentDomain, currentMailContent) {
      $scope.mailContent = currentMailContent;
      $scope.domain = currentDomain;

      $scope.remove = function() {
        var modalInstance = $modal.open({
          templateUrl: 'ng_components/common/confirm_modal.tpl.html',
          controller: 'ConfirmDialogCtrl',
          resolve: {
            content: function() {
              return 'MAIL_CONTENT.CONFIRM_DELETE_FORM.PARAGRAPH';
            }
          }
        });
        modalInstance.result.then(
          function validate() {
            MailContent.remove($scope.mailContent).then(function() {
              $scope.cancel();
            });
          }, function cancel() {
            $log.debug('Deletion modal dismissed');
          }
        );
      };
      $scope.update = function() {
        MailContent.update($scope.mailContent).then(function() {
          $scope.cancel();
        });
      };
      $scope.cancel = function() {
        $state.go('mailcontent.list', {domainId: $state.params.domainId, language: $state.params.language});
      };
      $scope.reset = function() {
        $state.reinit();
      };
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('MailContentListCtrl',
            ['$scope', '$filter', '$log', '$modal', '$state', 'ngTableParams', 'mailContents', 'currentDomain', 'Languages',
    function($scope, $filter, $log, $modal, $state, ngTableParams, mailContents, currentDomain, Languages) {
      $scope.domain = currentDomain;

      $scope.add = function() {
        var modalInstance = $modal.open({
          controller: 'mailContentModalCtrl',
          templateUrl: 'ng_components/mailcontent/mailcontent_modal.tpl.html'
        });
      };
      $scope.filters = {
        language: Languages.langCmp($state.params.language).filter
      };
      $scope.$watch('filters.language',
        function(newValue) {
          $state.go('.', {domainId: $state.params.domainId, language: newValue});
        }
      );
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        filter: $scope.filters,
        sorting: {
          name: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var filteredData = params.filter() ?
                    $filter('filter')(mailContents, params.filter()) :
                    mailContents;
          var orderedData = params.sorting() ?
                    $filter('orderBy')(filteredData, params.orderBy()) :
                    filteredData;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('mailContentModalCtrl',
    ['$scope', '$log', '$translate', '$state', '$modalInstance', 'Domain', 'Enum', 'MailContent',
      function ($scope, $log, $translate, $state, $modalInstance, Domain, Enum, MailContent) {
        Enum.getOptions('mail_content_type').then(function(options) {
          $scope.mailContentTypes = options;
        });
        Domain.getAll().then(function(domains) {
          $scope.domains = domains;
        });
        $scope.isDefined = function(x) {
          return angular.isDefined(x);
        };
        $scope.reloadModels = function(lang, domain, mailContentType) {
          if (angular.isDefined(domain) &&
              angular.isDefined(lang) &&
              angular.isDefined(mailContentType)) {
            MailContent.getAll(Domain.getId(domain), false).then(function(models) {
              $scope.models = models;
            });
          }
        };
        $scope.create = function (model) {
          var originalModel = model.originalElement;
          delete originalModel.name;
          angular.extend($scope.mailContent, originalModel);
          delete $scope.mailContent.uuid;
          delete $scope.mailContent.creationDate;
          delete $scope.mailContent.modificationDate;
          $scope.mailContent.domain = $state.params.domainId;
          MailContent.add($scope.mailContent).then(function() {
            $modalInstance.close();
            $scope.reset();
            $state.reinit();
          });
        };
        $scope.cancel = function () {
          $modalInstance.dismiss('cancel');
          $scope.reset();
        };
        $scope.reset = function() {
          $scope.mailContent = {};
        };
        $scope.reset();
      }
    ]
  );

'use strict';

angular.module('linshareAdminApp')
  .factory('MailContentLang',
    ['$log', 'Notification', 'Restangular',
    function ($log, Notification, Restangular) {
      //var self = this;

      // Public API here
      return {
        get: function(mailContentLangId) {
          $log.debug('MailContenLang:get');
          return Restangular.one('mail_content_langs', mailContentLangId).get();
        },
        update: function(mailContentLang) {
          $log.debug('MailContentLang:update');
          return mailContentLang.put().then(function() {
            Notification.addSuccess('UPDATE');
          });
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('MailContentLangDetailCtrl',
    ['$scope', '$log', '$modal',  '$state', 'MailContentLang', 'currentMailContentLang', 'mailContents',
    function($scope, $log, $modal, $state, MailContentLang, currentMailContentLang, mailContents) {
      $scope.mailContentLang = currentMailContentLang;
      $scope.mailContents = mailContents;

      $scope.update = function() {
        MailContentLang.update($scope.mailContentLang).then(function() {
          $scope.cancel();
        });
      };
      $scope.reset = function() {
        $state.reinit();
      };
      $scope.cancel = function() {
        $state.go("mailconfig.detail", {id: $state.params.mailConfigId, language: $scope.mailContentLang.language, domainId: $state.params.domainId});
      };
    }]
  );

'use strict';

angular.module('linshareAdminApp')
  .factory('MailFooter',
    ['$log', 'Notification', 'Restangular',
    function ($log, Notification, Restangular) {
      //var self = this;

      // Public API here
      return {
        getAll: function(domainId, onlyCurrentDomain) {
          $log.debug('MailFooter:getAll');
          return Restangular.all('mail_footers')
            .getList({domainId: domainId, onlyCurrentDomain: onlyCurrentDomain});
        },
        get: function(domainId, mailFooterId) {
          $log.debug('MailFooter:get');
          return Restangular.one('mail_footers', mailFooterId)
            .get({domainId: domainId});
        },
        add: function(mailFooter) {
          $log.debug('MailFooter:add');
          return Restangular.all('mail_footers').post(mailFooter).then(function() {
            Notification.addSuccess('CREATE');
          });
        },
        update: function(mailFooter) {
          $log.debug('MailFooter:update');
          return mailFooter.put().then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        remove: function(mailFooter) {
          $log.debug('MailFooter:remove');
          return mailFooter.remove().then(function() {
            Notification.addSuccess('DELETE');
          });
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('MailFooterDetailCtrl',
    ['$scope', '$log', '$modal',  '$state', 'MailFooter', 'currentDomain', 'currentMailFooter',
    function($scope, $log, $modal, $state, MailFooter, currentDomain, currentMailFooter) {
      $scope.mailFooter = currentMailFooter;
      $scope.domain = currentDomain;

      $scope.remove = function() {
        var modalInstance = $modal.open({
          templateUrl: 'ng_components/common/confirm_modal.tpl.html',
          controller: 'ConfirmDialogCtrl',
          resolve: {
            content: function() {
              return 'MAIL_FOOTER.CONFIRM_DELETE_FORM.PARAGRAPH';
            }
          }
        });
        modalInstance.result.then(
          function validate() {
            MailFooter.remove($scope.mailFooter).then(function() {
              $scope.cancel();
            });
          }, function cancel() {
            $log.debug('Deletion modal dismissed');
          }
        );
      };
      $scope.update = function() {
        MailFooter.update($scope.mailFooter).then(function() {
          $scope.cancel();
        });
      };
      $scope.cancel = function() {
        $state.go('mailfooter.list', {domainId: $state.params.domainId, language: $state.params.language});
      };
      $scope.reset = function() {
        $state.reinit();
      };
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('MailFooterListCtrl',
    ['$scope', '$filter', '$log', '$modal', '$state', 'ngTableParams', 'mailFooters', 'currentDomain', 'Languages',
    function($scope, $filter, $log, $modal, $state, ngTableParams, mailFooters, currentDomain, Languages) {
      $scope.domain = currentDomain;

      $scope.add = function() {
        var modalInstance = $modal.open({
          controller: 'mailFooterModalCtrl',
          templateUrl: 'ng_components/mailfooter/mailfooter_modal.tpl.html'
        });
      };
      $scope.filters = {
        language: Languages.langCmp($state.params.language).filter
      };
      $scope.$watch('filters.language',
        function(newValue) {
          $state.go('.', {domainId: $state.params.domainId, language: newValue});
        }
      );
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        filter: $scope.filters,
        sorting: {
          name: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var filteredData = params.filter() ?
                    $filter('filter')(mailFooters, params.filter()) :
                    mailFooters;
          var orderedData = params.sorting() ?
                    $filter('orderBy')(filteredData, params.orderBy()) :
                    filteredData;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );

'use strict';

angular.module('linshareAdminApp')
  .controller('mailFooterModalCtrl',
    ['$scope', '$log', '$translate', '$state', '$modalInstance', 'Domain', 'MailFooter',
      function ($scope, $log, $translate, $state, $modalInstance, Domain, MailFooter) {
        Domain.getAll().then(function(domains) {
          $scope.domains = domains;
        });
        $scope.isDefined = function(x) {
          return angular.isDefined(x);
        };
        $scope.reloadModels = function(lang, domain) {
          if (angular.isDefined(domain) &&
              angular.isDefined(lang)) {
            MailFooter.getAll(domain.identifier, false).then(function(models) {
              $scope.models = models;
            });
          }
        };
        $scope.create = function (model) {
          var originalModel = model.originalElement;
          delete originalModel.name;
          angular.extend($scope.mailFooter, originalModel);
          delete $scope.mailFooter.uuid;
          delete $scope.mailFooter.creationDate;
          delete $scope.mailFooter.modificationDate;
          $scope.mailFooter.domain = $state.params.domainId;
          MailFooter.add($scope.mailFooter).then(function() {
            $modalInstance.close();
            $scope.reset();
            $state.reinit();
          });
        };
        $scope.cancel = function () {
          $modalInstance.dismiss('cancel');
          $scope.reset();
        };
        $scope.reset = function() {
          $scope.mailFooter = {};
        };
        $scope.reset();
      }
    ]
  );

'use strict';

angular.module('linshareAdminApp')
  .factory('MailFooterLang',
    ['$log', 'Notification', 'Restangular',
    function ($log, Notification, Restangular) {
      //var self = this;

      // Public API here
      return {
        get: function(mailFooterLangId) {
          $log.debug('MailContenLang:get');
          return Restangular.one('mail_footer_langs', mailFooterLangId).get();
        },
        update: function(mailFooterLang) {
          $log.debug('MailFooterLang:update');
          return Restangular.all('mail_footer_langs').customPUT(mailFooterLang).then(function() {
            Notification.addSuccess('UPDATE');
          });
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .factory('MailingList', ['$log', 'Restangular', 'Notification',
    function ($log, Restangular, Notification) {
      //var self = this;

      // Public API here
      return {
        getAll: function() {
          $log.debug('MailingList:getAll');
          return Restangular.all('lists').getList();
        },
        get: function(mailId) {
          $log.debug('MailingList:get');
          return Restangular.one('lists', mailId).get();
        },
        update: function(mail) {
          $log.debug('MailingList:update');
          return mail.put().then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        remove: function(mail) {
          $log.debug('MailingList:remove');
          return mail.remove().then(function() {
            Notification.addSuccess('DELETE');
          });
        },
        addContact: function(mailId, contact) {
          $log.debug('MailingList:addContact');
          return Restangular.one('lists', mailId).all('contacts').customPOST(contact);
        },
        removeContact: function(mailId, contact) {
          $log.debug('MailingList:removeContact');
          return Restangular.one('lists', mailId).all('contacts').customOperation('remove', '', {}, {}, contact);
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('MailingListDetailCtrl',
    ['$scope', '$filter', '$log', '$state', 'ngTableParams', 'MailingList', 'User', 'currentMailingList',
    function($scope, $filter, $log, $state, ngTableParams, MailingList, User, currentMailingList){
      $scope.mail = currentMailingList;

      $scope.remove = function() {
        MailingList.remove($scope.mail).then(function() {
          $scope.cancel();
        });
      };
      $scope.reset = function() {
        $state.reinit();
      };
      $scope.cancel = function() {
        $state.go('mailinglist.list');
      };
      $scope.submit = function(mail) {
        MailingList.update(mail).then(function() {
          $scope.cancel();
        });
      };
      $scope.autocompleteUsers = function(pattern) {
        return User.autocomplete(pattern).then(function(users) {
          // Remove existing contacts
          angular.forEach($scope.tableParams.data, function(contact) {
            angular.forEach(users, function(user, key) {
              if (user.firstName === contact.firstName
                    && user.lastName === contact.lastName
                    && user.mail === contact.mail) {
                users.splice(key, 1);
              }
            });
          });
          return users;
        });
      };
      $scope.fieldForm = function(contactToAdd) {
        // Override the typeahead input
        $scope.autocompleteValue = contactToAdd.mail;
        $scope.contactToAdd = contactToAdd;
      };
      $scope.addContact = function() {
        var contact = {
          'mail': $scope.autocompleteValue,
          'firstName': $scope.contactToAdd.firstName,
          'lastName': $scope.contactToAdd.lastName
        };
        MailingList.addContact($scope.mail.uuid, contact).then(function() {
          $scope.reloadList();
          $scope.contactToAdd = undefined;
          $scope.autocompleteValue = undefined;
        });
      };
      $scope.deleteContact = function(contact) {
        MailingList.removeContact($scope.mail.uuid, contact).then(function() {
          $scope.reloadList();
        });
      };
      $scope.reloadList = function () {
        $scope.tableParams.reload();
      };
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          firstName: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          MailingList.get($scope.mail.uuid).then(function(mail) {
            var orderedData = params.sorting() ?
                                $filter('orderBy')(mail.contacts, params.orderBy()) :
                                mail.contacts;
            params.total(orderedData.length);
            $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
          });
        }
      });
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('MailingListListCtrl',
    ['$scope', '$filter', '$log', 'ngTableParams', 'mailingLists',
    function($scope, $filter, $log, ngTableParams, mailingLists) {

      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          identifier: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var orderedData = params.sorting() ?
                              $filter('orderBy')(mailingLists, params.orderBy()) :
                              mailingLists;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );

'use strict';

angular.module('linshareAdminApp')
  .factory('MailLayout',
    ['$log', 'Notification', 'Restangular',
    function ($log, Notification, Restangular) {
      //var self = this;

      // Public API here
      return {
        getAll: function(domainId, onlyCurrentDomain) {
          $log.debug('MailLayout:getAll');
          return Restangular.all('mail_layouts')
            .getList({domainId: domainId, onlyCurrentDomain: onlyCurrentDomain});
        },
        get: function(domainId, mailLayoutId) {
          $log.debug('MailLayout:get');
          return Restangular.one('mail_layouts', mailLayoutId).get({domainId: domainId});
        },
        add: function(mailLayout) {
          $log.debug('MailLayout:add');
          return Restangular.all('mail_layouts').post(mailLayout).then(function() {
            Notification.addSuccess('CREATE');
          });
        },
        update: function(mailLayout) {
          $log.debug('MailLayout:update');
          return mailLayout.put().then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        remove: function(mailLayout) {
          $log.debug('MailLayout:remove');
          return mailLayout.remove().then(function() {
            Notification.addSuccess('DELETE');
          });
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('MailLayoutDetailCtrl',
    ['$scope', '$log', '$modal', '$state', 'MailLayout', 'currentDomain', 'currentMailLayout',
    function($scope, $log, $modal, $state, MailLayout, currentDomain, currentMailLayout) {
      $scope.mailLayout = currentMailLayout;
      $scope.domain = currentDomain;

      $scope.remove = function() {
        var modalInstance = $modal.open({
          templateUrl: 'ng_components/common/confirm_modal.tpl.html',
          controller: 'ConfirmDialogCtrl',
          resolve: {
            content: function() {
              return 'MAIL_LAYOUT.CONFIRM_DELETE_FORM.PARAGRAPH';
            }
          }
        });
        modalInstance.result.then(
          function validate() {
            MailLayout.remove($scope.mailLayout).then(function() {
                $scope.cancel();
            });
          }, function cancel() {
            $log.debug('Deletion modal dismissed');
          }
        );
      };
      $scope.update = function() {
        MailLayout.update($scope.mailLayout).then(function() {
          $scope.cancel();
        });
      };
      $scope.cancel = function() {
        $state.go('maillayout.list', {domainId: $state.params.domainId});
      };
      $scope.reset = function() {
        $state.reinit();
      };
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('MailLayoutListCtrl',
    ['$scope', '$filter', '$log', '$modal', 'ngTableParams', 'mailLayouts', 'currentDomain',
    function($scope, $filter, $log, $modal, ngTableParams, mailLayouts, currentDomain) {
      $scope.domain = currentDomain;

      $scope.add = function() {
        var modalInstance = $modal.open({
          controller: 'mailLayoutModalCtrl',
          templateUrl: 'ng_components/maillayout/maillayout_modal.tpl.html'
        });
      };
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          name: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var orderedData = params.sorting() ?
                    $filter('orderBy')(mailLayouts, params.orderBy()) :
                    mailLayouts;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );



'use strict';

angular.module('linshareAdminApp')
  .controller('mailLayoutModalCtrl',
    ['$scope', '$log', '$state', '$modalInstance', 'Domain', 'MailLayout',
      function ($scope, $log, $state, $modalInstance, Domain, MailLayout) {
        Domain.getAll().then(function(domains) {
          $scope.domains = domains;
        });
        $scope.isDefined = function(x) {
          return angular.isDefined(x);
        };
        $scope.reloadModels = function(domain) {
          if (angular.isDefined(domain)) {
            MailLayout.getAll(Domain.getId(domain), false).then(function(models) {
              $scope.models = models;
            });
          }
        };
        $scope.create = function (model) {
          var originalModel = model.originalElement;
          delete originalModel.name;
          angular.extend($scope.mailLayout, originalModel);
          delete $scope.mailLayout.uuid;
          delete $scope.mailLayout.creationDate;
          delete $scope.mailLayout.modificationDate;
          $scope.mailLayout.domain = $state.params.domainId;
          MailLayout.add($scope.mailLayout).then(function() {
            $modalInstance.close();
            $scope.reset();
            $state.reinit();
          });
        };
        $scope.cancel = function () {
          $modalInstance.dismiss('cancel');
          $scope.reset();
        };
        $scope.reset = function() {
          $scope.mailLayout = {};
        };
        $scope.reset();
      }
    ]
  );

'use strict';

angular.module('linshareAdminApp')
  .factory('MimePolicy',
    ['$log', 'Notification', 'Restangular',
    function ($log, Notification, Restangular) {
      //var self = this;

      // Public API here
      return {
        getAll: function(domainId, onlyCurrentDomain) {
          $log.debug('MimePolicy:getAll');
          return Restangular.all('mime_policies')
            .getList({domainId: domainId, onlyCurrentDomain: onlyCurrentDomain});
        },
        get: function(mimePolicyId, full) {
          $log.debug('MimePolicy:get');
          return Restangular.one('mime_policies', mimePolicyId).get({full: full});
        },
        add: function(mimePolicy) {
          $log.debug('MimePolicy:add');
          return Restangular.all('mime_policies').post(mimePolicy).then(function() {
            Notification.addSuccess('CREATE');
          });
        },
        update: function(mimePolicy) {
          $log.debug('MimePolicy:update');
          return mimePolicy.put().then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        enableAllMimeTypes: function(mimePolicyId) {
          $log.debug('MimePolicy:enableAllMimeTypes');
          return Restangular.one('mime_policies', mimePolicyId).customPUT(null, 'enable_all');
        },
        disableAllMimeTypes: function(mimePolicyId) {
          $log.debug('MimePolicy:disableAllMimeTypes');
          return Restangular.one('mime_policies', mimePolicyId).customPUT(null, 'disable_all');
        },
        remove: function(mimePolicy) {
          $log.debug('MimePolicy:remove');
          return mimePolicy.remove().then(function() {
            Notification.addSuccess('DELETE');
          });
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('MimePolicyDetailCtrl',
    ['$scope', '$filter', '$timeout', '$log', '$modal', '$state', 'ngTableParams', 'MimePolicy', 'MimeType', 'currentMimePolicy',
    function($scope, $filter, $timeout, $log, $modal, $state, ngTableParams, MimePolicy, MimeType, currentMimePolicy) {
          $scope.mimePolicy = currentMimePolicy;
          $scope.iconSaved = false;

          $scope.remove = function() {
            var modalInstance = $modal.open({
              templateUrl: 'ng_components/common/confirm_modal.tpl.html',
              controller: 'ConfirmDialogCtrl',
              resolve: {
                content: function() {
                  return 'MIME_POLICIES.CONFIRM_DELETE_FORM.PARAGRAPH';
                }
              }
            });
            modalInstance.result.then(
              function validate() {
                MimePolicy.remove($scope.mimePolicy).then(function() {
                    $scope.cancel();
                });
              }, function cancel() {
                $log.debug('Deletion modal dismissed');
              }
            );
          };
          $scope.displayIconSaved = function() {
            $scope.iconSaved = true;
            $timeout(function() {
              $scope.iconSaved = false;
            }, 800);
          };
          $scope.update = function() {
            MimePolicy.update($scope.mimePolicy).then(function() {
              $scope.cancel();
            });
          };
          $scope.updateMimeType = function(mimeType) {
            MimeType.update(mimeType, function() {
              $scope.displayIconSaved();
            });
          };
          $scope.enableAllMimeTypes = function(mimeConfig) {
            MimePolicy.enableAllMimeTypes(mimeConfig.uuid).then(function() {
              $scope.displayIconSaved();
              $scope.reset();
            });
          };
          $scope.disableAllMimeTypes = function(mimeConfig) {
            MimePolicy.disableAllMimeTypes(mimeConfig.uuid).then(function() {
              $scope.displayIconSaved();
              $scope.reset();
            });
          };
          $scope.cancel = function() {
            $state.go('mimepolicy.list', {domainId: currentMimePolicy.domainId});
          };
          $scope.reset = function() {
            $state.reinit();
          };
          $scope.tableParams = new ngTableParams({
            page: 1,        // show first page
            count: 10,      // count per page
            sorting: {
              enable: 'asc',
            }
          }, {
            debugMode: false,
            total: 0, // length of data
            getData: function($defer, params) {
              var filteredData = params.filter() ?
                        $filter('filter')($scope.mimePolicy.mimeTypes, params.filter()) :
                        $scope.mimePolicy.mimeTypes;
              var orderedData = params.sorting() ?
                        $filter('orderBy')(filteredData, params.orderBy()) :
                        filteredData;
              params.total(orderedData.length);
              $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
            },
            $scope: { $data: {}, $emit: function() {} }
          });
    }]
  )

'use strict';

angular.module('linshareAdminApp')
  .controller('MimePolicyListCtrl',
    ['$scope', '$filter', '$log', '$modal', 'ngTableParams', 'currentDomain', 'mimePolicies',
    function($scope, $filter, $log, $modal, ngTableParams, currentDomain, mimePolicies) {
      $scope.domain = currentDomain;

      $scope.add = function() {
        var modalInstance = $modal.open({
          controller: 'mimePolicyModalCtrl',
          templateUrl: 'ng_components/mimepolicy/mimepolicy_modal.tpl.html'
        });
        modalInstance.result.then(function () {
          $scope.tableParams.reload();
        });
      };
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          name: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var filteredData = params.filter() ?
                    $filter('filter')(mimePolicies, params.filter()) :
                    mimePolicies;
          var orderedData = params.sorting() ?
                    $filter('orderBy')(filteredData, params.orderBy()) :
                    filteredData;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('mimePolicyModalCtrl',
    ['$scope', '$log', '$state', '$modalInstance', 'MimePolicy',
      function ($scope, $log, $state, $modalInstance, MimePolicy) {
        $scope.create = function () {
          MimePolicy.add($scope.mimePolicy).then(function() {
            $modalInstance.close();
            $state.reinit();
          });
        };
        $scope.cancel = function () {
          $modalInstance.dismiss('cancel');
          $scope.reset();
        };
        $scope.reset = function() {
          $scope.mimePolicy = {
            domainId: $state.params.domainId
          };
        };
        $scope.reset();
      }
    ]
  );

'use strict';

angular.module('linshareAdminApp')
  .controller('PasswordCtrl',
    ['$scope', '$location', '$log', 'Authentication', 'Password',
      function ($scope, $location, $log, Authentication, Password) {
        $scope.newPwdRetyped = '';
        $scope.password = {
          'oldPwd' : '',
          'newPwd' : ''
        };
        $scope.match = function(a, b) {
          return Password.match(a, b);
        };
        $scope.strengthScore = function(password) {
          return Password.strengthScore(password);
        };
        $scope.redirectToHome = function () {
          $location.path('/');
        };
        $scope.submit = function() {
          Authentication.changePassword($scope.password).then(function() {
            $location.path('/');
          });
        };
      }
    ]
  );

'use strict';

angular.module('linshareAdminApp')
  .service('Password', function Password() {
    function Rule(description, validator) {
      this.description = description;
      this.validator = function(pwd) {
        return validator(pwd);
      };
    }
    this.rules = [
      new Rule('Contain a symbol', function (pwd) {
        return pwd && /[$-/:-?{-~!"^_`\[\]]/g.test(pwd);
      }),
      new Rule('Length longer than 8 char', function (pwd) {
        return pwd && pwd.length >= 8;
      }),
      new Rule('Contain a digit', function (pwd) {
        return pwd && /[0-9]+/.test(pwd);
      }),
      new Rule('Contain an upper case character', function (pwd) {
        return pwd && /[A-Z]+/.test(pwd);
      }),
      new Rule('Contain a lower case character', function (pwd) {
        return pwd && /[a-z]+/.test(pwd);
      })
    ];

    var self = this;
    
    return {
      strengthScore: function(password) {
        var strength = 0;
        angular.forEach(self.rules, function(r) {
          strength += r.validator(password);
        });
        return strength * 100 / self.rules.length;
      },
      match: function(a, b) {
        return a === b;
      }
    };
  });

'use strict';

angular.module('linshareAdminApp')
  .factory('TechnicalAccount', ['$log', 'Notification', 'Restangular',
    function ($log, Notification, Restangular) {
      //var self = this;

      // Public API here
      return {
        getAll: function() {
          $log.debug('TechnicalAccount:getAll');
          return Restangular.all('technical_accounts').getList();
        },
        get: function(id) {
          $log.debug('TechnicalAccount:get');
          return Restangular.one('technical_accounts', id).get();
        },
        add: function(account) {
          $log.debug('TechnicalAccount:add');
          return Restangular.all('technical_accounts').post(account).then(function() {
            Notification.addSuccess('CREATE');
          });
        },
        update: function(account) {
          $log.debug('TechnicalAccount:update');
          return account.put().then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        changePassword: function(accountId, password) {
          $log.debug('TechnicalAccount:changePassword');
          return Restangular.all('technical_accounts').all(accountId).all('change_password').post(password).then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        remove: function(account) {
          $log.debug('TechnicalAccount:remove');
          return account.remove().then(function() {
            Notification.addSuccess('DELETE');
          });
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('TechnicalAccountDetailCtrl',
    ['$scope', '$state', '$modal', '$log', 'Password', 'TechnicalAccount', 'currentTechnicalAccount', 'selectOptions',
    function($scope, $state, $modal, $log, Password, TechnicalAccount, currentTechnicalAccount, selectOptions) {
      $scope.state = $state.params.formState;
      $scope.account = currentTechnicalAccount || {};
      $scope.permissionTypes = selectOptions.permissionTypes;
      if ($scope.state === 'create') {
        $scope.account.password = '';
      }

      $scope.tmp = {
        'newPwdRetyped1': '',
        'newPwdRetyped2': ''
      };
      $scope.password = {
        'oldPwd' : '',
        'newPwd' : ''
      };
      $scope.strengthScore = function(password) {
        return Password.strengthScore(password);
      };
      $scope.match = function(a, b) {
        return Password.match(a, b);
      }
      $scope.changePassword = function() {
        TechnicalAccount.changePassword($scope.account.uuid, $scope.password);
      };
      $scope.submit = function() {
        if ($scope.state === 'edit') {
          TechnicalAccount.update($scope.account).then(function() {
            $scope.cancel();
          });
        } else if ($scope.state === 'create') {
          TechnicalAccount.add($scope.account).then(function() {
            $scope.cancel();
          });
        } else {
          $log.error('Invalid state');
        }
      };
      $scope.remove = function() {
        if ($scope.state != 'edit') {
          $log.error('Invalid state');
        }
        var modalInstance = $modal.open({
          templateUrl: 'ng_components/common/confirm_modal.tpl.html',
          controller: 'ConfirmDialogCtrl',
          resolve: {
            content: function() {
              return 'TECHNICAL_ACCOUNT.CONFIRM_DELETE_FORM.PARAGRAPH';
            }
          }
        });
        modalInstance.result.then(
          function validate() {
            TechnicalAccount.remove($scope.account).then(function() {
              $scope.cancel();
            });
          }, function cancel() {
            $log.debug('Deletion modal dismissed');
          }
        );
      };
      $scope.cancel = function() {
        $state.go('technicalaccount.list');
      };
      $scope.reset = function() {
        $state.reinit();
      };
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('TechnicalAccountListCtrl',
    ['$scope', '$filter', '$log', 'ngTableParams', 'technicalAccounts',
    function($scope, $filter, $log, ngTableParams, technicalAccounts) {

      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          name: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var orderedData = params.sorting() ?
                              $filter('orderBy')(technicalAccounts, params.orderBy()) :
                              technicalAccounts;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .factory('Thread', ['$q', '$log', 'Restangular', 'Notification',
    function ($q, $log, Restangular, Notification) {
      //var self = this;

      // Public API here
      return {
        getAll: function(pattern) {
          $log.debug('Thread:getAll');
          if (pattern == null)
            return Restangular.all('threads').getList();
          return Restangular.all('threads').getList({pattern:pattern});
        },
        get: function(id) {
          $log.debug('Thread:get');
          return Restangular.one('threads', id).get();
        },
        update: function(thread) {
          $log.debug('Thread:update');
          return thread.put().then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        remove: function(thread) {
          $log.debug('Thread:remove');
          return thread.remove().then(function() {
            Notification.addSuccess('DELETE');
          });
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('ThreadDetailCtrl',
    ['$scope', '$filter', '$log', '$state', 'ngTableParams', 'Thread', 'ThreadMember', 'User', 'currentThread',
    function($scope, $filter, $log, $state, ngTableParams, Thread, ThreadMember, User, currentThread) {
      $scope.thread = currentThread;

      $scope.reloadList = function () {
        $scope.tableParams.reload();
      };
      $scope.remove = function() {
        Thread.remove($scope.thread).then(function() {
          $scope.cancel();
        });
      };
      $scope.reset = function() {
        $state.reinit();
      };
      $scope.cancel = function() {
        $state.go('thread.list');
      };
      $scope.submit = function() {
        Thread.update($scope.thread).then(function() {
          $scope.cancel();
        });
      };
      $scope.addMember = function(member) {
        ThreadMember.add($scope.thread, member).then(function() {
          $scope.reloadList();
          $scope.userToAdd = undefined;
        });
      };
      $scope.autocompleteUsers = function(pattern) {
        return User.autocomplete(pattern).then(function(users) {
          // Remove existing members
          angular.forEach($scope.tableParams.data, function(threadMember) {
            angular.forEach(users, function(user, key) {
              if (user.domain === threadMember.userDomainId
                    && user.mail === threadMember.userMail) {
                users.splice(key, 1);
              }
            });
          });
          return users;
        });
      };
      $scope.updateMember = function(member) {
        ThreadMember.update(member);
      };
      $scope.deleteMember = function(member) {
        ThreadMember.remove(member).then(function() {
          $scope.reloadList();
        });
      };
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          firstName: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          ThreadMember.getAll($scope.thread).then(function(threadMembers) {
            var orderedData = params.sorting() ?
                                $filter('orderBy')(threadMembers, params.orderBy()) :
                                threadMembers;
            params.total(orderedData.length);
            $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
          });
        }
      });
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('ThreadListCtrl',
    ['$scope', '$filter', '$log', 'ngTableParams', 'Thread',
    function($scope, $filter, $log, ngTableParams, Thread) {
      $scope.$watch('threadSearch', function(newValue){
        if(newValue) $scope.searchEntry = newValue;
        else $scope.searchEntry = null;
      });
      var canRequest = false;
      $scope.isClicked = function(){
        canRequest = true;
        $scope.tableParams.reload();
      };
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          name: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          if (canRequest) {
            Thread.getAll($scope.searchEntry).then(function(thread) {
              thread = params.sorting() ?
                $filter('orderBy')(thread, params.orderBy()) :
                thread;
              params.total(thread.length);
              $defer.resolve(thread.slice((params.page() - 1) * params.count(), params.page() * params.count()));
            });
          }
        }
      });

    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .factory('ThreadMember', ['$log', 'Restangular',
    function ($log, Restangular) {
      var getThreadMemberDto = function(thread, user) {
        return {
          'threadUuid': thread.uuid,
          'userUuid': user.uuid,
          'userMail': user.mail,
          'userDomainId': user.domain
        };
      };

      // var self = this;

      // Public API here
      return {
        getAll: function(thread) {
          $log.debug('ThreadMember:getAll');
          return Restangular.one('threads', thread.uuid).all('members').getList();
        },
        add: function(thread, user) {
          $log.debug('ThreadMember:add');
          var threadMember = getThreadMemberDto(thread, user);
          return Restangular.all('thread_members').post(threadMember);
        },
        update: function(threadMember) {
          $log.debug('ThreadMember:update');
          return Restangular.all('thread_members').customPUT(threadMember);
        },
        remove: function(threadMember) {
          $log.debug('ThreadMember:remove');
          return Restangular.all('thread_members').customOperation('remove', '', {}, {}, threadMember);
        }
      };
    }
  ]
);


'use strict';

angular.module('linshareAdminApp')
  .factory('UploadPropositionFilter', ['$log', 'Notification', 'Restangular',
    function ($log, Notification, Restangular) {
      //var self = this;

      // Public API here
      return {
        getAll: function() {
          $log.debug('UploadPropositionFilter:getAll');
          return Restangular.all('upload_proposition_filters').getList();
        },
        get: function(id) {
          $log.debug('UploadPropositionFilter:get');
          return Restangular.one('upload_proposition_filters', id).get();
        },
        add: function(filter) {
          $log.debug('UploadPropositionFilter:add');
          return Restangular.all('upload_proposition_filters').post(filter).then(function() {
            Notification.addSuccess('CREATE');
          });
        },
        update: function(filter, notify) {
          $log.debug('UploadPropositionFilter:update');
          notify = typeof notify !== 'undefined' ? notify : true;
          return filter.put().then(function() {
            if (notify) {
              Notification.addSuccess('UPDATE');
            }
          });
        },
        remove: function(filter) {
          $log.debug('UploadPropositionFilter:remove');
          return filter.remove().then(function() {
            Notification.addSuccess('DELETE');
          });
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('UploadPropositionFilterDetailCtrl',
    ['$scope', '$state', '$log', 'selectOptions', 'UploadPropositionFilter', 'currentUploadPropositionFilter',
    function($scope, $state, $log, selectOptions, UploadPropositionFilter, currentUploadPropositionFilter) {
      $scope.filter = currentUploadPropositionFilter || {};
      $scope.state = $state.params.formState;
      $scope.fieldTypes = selectOptions.fieldTypes;
      $scope.operatorTypes = selectOptions.operatorTypes;
      $scope.actionTypes = selectOptions.actionTypes;
      $scope.matchTypes = selectOptions.matchTypes;
      if ($scope.state === 'create') {
        $scope.filter.uploadPropositionRules = [];
        $scope.filter.uploadPropositionActions = [];
        $scope.filter.uploadPropositionActions[0] = {};
        $scope.filter.match = 'TRUE'
      }

      $scope.addRule = function() {
        $scope.filter.uploadPropositionRules.push({});
      };
      $scope.deleteRule = function(index) {
        $scope.filter.uploadPropositionRules.splice(index, 1);
      };
      $scope.submit = function() {
        //$scope.filters.uploadPropositionRules = _.filter($scope.filters.uploadPropositionRules, function(obj) { return obj != {} ; });
        if ($scope.state === 'create') {
          UploadPropositionFilter.add($scope.filter).then(function () {
            $scope.cancel();
          });
        } else {
          UploadPropositionFilter.update($scope.filter).then(function () {
            $scope.cancel();
          });
        }
      };
      $scope.remove = function() {
        if ($scope.state != 'edit') {
          $log.error('Invalid state');
        }
        UploadPropositionFilter.remove($scope.filter).then(function() {
          $scope.cancel();
        });
      };
      $scope.cancel = function() {
        $state.go('uploadpropositionfilter.list');
      };
      $scope.reset = function() {
        $state.reinit();
      };
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .controller('UploadPropositionFilterListCtrl',
    ['$scope', '$filter', '$log', 'ngTableParams', 'UploadPropositionFilter', 'uploadPropositionFilters',
    function($scope, $filter, $log, ngTableParams, UploadPropositionFilter, uploadPropositionFilters) {

      $scope.swap = function(x, y, data) {
        data[x].order = y;
        data[y].order = x;
        UploadPropositionFilter.update(data[x], false).then(function() { // Disable one notify
          UploadPropositionFilter.update(data[y]).then(function() {
            $scope.reloadList();
          });
        });
      };
      $scope.reloadList = function () {
        $scope.tableParams.reload();
      };
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          order: 'asc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          var orderedData = params.sorting() ?
                              $filter('orderBy')(uploadPropositionFilters, params.orderBy()) :
                              uploadPropositionFilters;
          params.total(orderedData.length);
          $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
        }
      });
    }]
  );

'use strict';

angular.module('linshareAdminApp')
  .factory('UploadRequest', ['$log', 'Restangular',
    function ($log, Restangular) {
      // var self = this;

      // Public API here
      return {
        query: function(criteria) {
          $log.debug('UploadRequest:query');
          return Restangular.all('upload_requests').post(criteria);
        },
        history: function(uploadRequestUuid) {
          $log.debug('UploadRequest:history');
          return Restangular.all('upload_requests').one('history', uploadRequestUuid).getList();
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('UploadRequestFormCtrl',
    ['$scope', '$filter', '$log', 'ngTableParams', 'UploadRequest', 'uploadRequestStatus',
    function($scope, $filter, $log, ngTableParams, UploadRequest, uploadRequestStatus) {
      $scope.allStatus = uploadRequestStatus;

      $scope.criteria = {
        status: []
      };
      $scope.toggleSelection = function toggleSelection(s) {
        var idx = $scope.criteria.status.indexOf(s);
        if (idx > -1) {
          $scope.criteria.status.splice(idx, 1);
        } else {
          $scope.criteria.status.push(s);
        }
      };
      $scope.reloadList = function () {
        $scope.tableParams.reload();
      };
      $scope.opened = {
        from: false,
        to : false
      };
      $scope.humanFileSize = function(bytes, si) {
        var thresh = si ? 1000 : 1024;
        if (bytes < thresh) return bytes + ' B';
        var units = si ? ['kB','MB','GB','TB','PB','EB','ZB','YB'] : ['KiB','MiB','GiB','TiB','PiB','EiB','ZiB','YiB'];
        var u = -1;
        do {
          bytes /= thresh;
          ++u;
        } while (bytes >= thresh);
        return bytes.toFixed(1) + ' ' + units[u];
      };
      $scope.setCurrentUuid = function (uuid) {
        $scope.currentUuid = uuid;
        $scope.tableParamsHistory.reload();
      };
      $scope.open = function(key, $event) {
        $event.preventDefault();
        $event.stopPropagation();
        $scope.opened[key] = true;
      };
      $scope.tableParams = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          subject: 'desc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          UploadRequest.query($scope.criteria).then(function(uploadRequests) {
            $scope.currentUuid = undefined;
            var orderedData = params.sorting() ?
                                $filter('orderBy')(uploadRequests, params.orderBy()) :
                                uploadRequests;
            params.total(orderedData.length);
            $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
          });
        }
      });
      $scope.tableParamsHistory = new ngTableParams({
        page: 1,        // show first page
        count: 10,      // count per page
        sorting: {
          modificationDate: 'desc'
        }
      }, {
        debugMode: false,
        total: 0, // length of data
        getData: function($defer, params) {
          if ($scope.currentUuid) {
            UploadRequest.history($scope.currentUuid).then(function(history) {
              var orderedData = params.sorting() ?
                                  $filter('orderBy')(history, params.orderBy()) :
                                  history;
              params.total(orderedData.length);
              $defer.resolve(orderedData.slice((params.page() - 1) * params.count(), params.page() * params.count()));
            });
          } else {
            $defer.resolve();
          }
        }
      });
    }]
  );


'use strict';

angular.module('linshareAdminApp')
  .factory('User', ['$q', '$log', 'Restangular', 'Notification',
    function ($q, $log, Restangular, Notification) {
      // var self = this;

      // Public API here
      return {
        autocomplete: function(pattern) {
          $log.debug('User:autocomplete');
          return Restangular.all('users').one('autocomplete', pattern).get();
        },
        search: function(userSearchDto) {
          $log.debug('User:search');
          return Restangular.all('users').customPOST(userSearchDto, 'search').then(function(users) {
            angular.forEach(users, function(user) {
              user = Restangular.restangularizeElement(null, user, 'users');
            });
            var dfd = $q.defer();
            dfd.resolve(users);
            return dfd.promise;
          });
        },
        get: function(uuid) {
          $log.debug('User:get');
          return Restangular.one('users', uuid).get();
        },
        getAllInconsistent: function() {
          $log.debug('User:getAllInconsistent');
          return Restangular.all('users').all('inconsistent').getList();
        },
        update: function(user) {
          $log.debug('User:update');
          return user.put().then(function() {
            Notification.addSuccess('UPDATE');
          });
        },
        remove: function(user) {
          $log.debug('User:remove');
          return user.remove().then(function() {
            Notification.addSuccess('DELETE');
          });
        }
      };
    }
  ]
);

'use strict';

angular.module('linshareAdminApp')
  .controller('UserDetailCtrl',
     ['$scope', '$modal', '$state',  '$log', 'User', 'selectOptions', 'currentUser', 'maxExpiryDate', 'restrictedGuestStatus',
      function ($scope, $modal, $state, $log, User, selectOptions, currentUser, maxExpiryDate, restrictedGuestStatus) {
        $scope.userRoles = selectOptions.userRoles;
        $scope.userRolesSimple = ['SIMPLE', 'ADMIN'];
        $scope.user = currentUser;
        $scope.limit = maxExpiryDate;
        $scope.restrictedDisabled = restrictedGuestStatus;
        $scope.selectEnumLanguage = selectOptions.selectEnumLanguage;

        $scope.open = function($event) {
          $event.preventDefault();
          $event.stopPropagation();
          $scope.opened = true;
        };
        $scope.removeContact = function(user, index) {
          user.restrictedContacts.splice(index, 1);
        };
        $scope.addContact = function(user, contact) {
          if (!_.contains(user.restrictedContacts, contact.mail)) {
            user.restrictedContacts.push(contact.mail);
          }
        };
        $scope.cancel = function() {
          $state.go('user.list');
        };
        $scope.reset = function() {
          $state.reinit();
        };
        $scope.submit = function(user) {
          User.update($scope.user).then(function() {
            $scope.cancel();
          });
        };
        $scope.isGuest = function() {
          return $scope.user.accountType == 'GUEST';
        };
        $scope.delete = function(user) {
          var modalInstance = $modal.open({
            templateUrl: 'ng_components/common/confirm_modal.tpl.html',
            controller: 'ConfirmDialogCtrl',
            resolve: {
              content: function() {
                return 'MANAGE_USERS.CONFIRM_DELETE_FORM.PARAGRAPH';
              }
            }
          });
          modalInstance.result.then(
            function validate() {
              User.remove($scope.user).then(function() {
                $scope.cancel();
              });
            }, function cancel() {
              $log.debug('Deletion modal dismissed');
            }
          );
        };
      }
    ]
  );

'use strict';

angular.module('linshareAdminApp')
  .controller('UserListCtrl',
     ['$scope', '$filter', '$log', 'ngTableParams', 'User',
      function ($scope, $filter, $log, ngTableParams, User) {
        $scope.reloadList = function () {
          $scope.tableParams.reload();
        };
        $scope.tableParams = new ngTableParams({
          page: 1,        // show first page
          count: 10,      // count per page
          sorting: {
            lastName: 'asc'
          }
        }, {
          debugMode: false,
          total: 0, // length of data
          getData: function($defer, params) {
            var canRequest = false;
            angular.forEach(_.keys(params.filter()), function(key) {
              if (params.filter()[key].length >= 3) {
                canRequest = true;
              }
            });
            if (canRequest) {
              User.search(params.filter()).then(function(users) {
                users = params.sorting() ?
                                    $filter('orderBy')(users, params.orderBy()) :
                                    users;
                params.total(users.length);
                $defer.resolve(users.slice((params.page() - 1) * params.count(), params.page() * params.count()));
              });
            }
          }
        });
      }
    ]
  );
